# Sys Files

The Sys file policy is maintained in the `src/sysfile.cil`
module and in modules located in the `src/sysfile` directory.
Sys files are partitioned and are referenced at various levels
using `types` (sysfile) and `type attributes` (obj_typeattr).

* `sysfile.obj_typeattr` all Sys files
* `sysfile.block.obj_typeattr` all Sys Block files (`/sys/block`)
* `sysfile.bus.obj_typeattr` all Sys Bus files (`/sys/bus`)
* `sysfile.class.obj_typeattr` all Sys Class files (`/sys/class`)
* `sysfile.dev.obj_typeattr` all Sys Dev files (`/sys/dev`)
* `sysfile.devices.obj_typeattr` all Sys Devices files
(`/sys/devices`)
* `sysfile.firmware.obj_typeattr` all Sys Firmware files
(`/sys/firmware`)
* `sysfile.fs.obj_typeattr` all Sys FS files (`/sys/fs`)
* `sysfile.hypervisor.obj_typeattr` all Sys Hypervisor files
(`/sys/hypervisor`)
* `sysfile.kernel.obj_typeattr` all Sys Kernel files (`/sys/kernel`)
* `sysfile.module.obj_typeattr` all Sys Module files
(`/sys/module`)
* `sysfile.power.obj_typeattr` all Sys Power files (`/sys/power`)

Sys files are either "block", "bus", "class", "dev", "devices",
"firmware", "fs", "hypervisor", "kernel", "module" or "power".

The modules that facilitate access to Sys files at a lower level
abstract and inherit templates that are used to declare and provide
access to Sys file types and type attributes.

## src/sysfile.cil

The `src/sysfile.cil` module defines Sys files and access to
them at the lowest level namely "all Sys files". There is no
default Sys file type.

The `file.obj_all_macro_template` is only inherited in the
`sysfile` container to make a type attribute and macros available
that can be referenced to operate on all Sys files.

Sys files are files that associate with Sys filesystems. Types
associated with Sys files are therefore associated with the
`file.obj_typeattr` type attribute by calling the `file.obj_type`
macro declared in the `src/file.cil` module with the `obj_typeattr`
argument in the `sysfile` container and they are also associated
with a rule that allows these types to associate with Sys
filesystems by calling the `sys.associate_filesystems` macro
declared in the `src/fs/sysfs.cil` module with the `obj_typeattr`
argument in the `sysfile` container.

Available templates:

* `sysfile.obj_base_template` Declares a Sys file
* `sysfile.obj_all_macro_template` Macros that provide access to
all Sys files
* `sysfile.obj_macro_template` Macros that provide access to a
specified Sys file
* `sysfile.obj_template` Declares a Sys file and includes macros
that provide access to the declared Sys file

Macros providing access to `sysfile.obj_typeattr` are created by
inheriting `file.obj_all_macro_template` in the `sysfile`
container:

* `sysfile.addname_all_dirs`
* `sysfile.append_all_blk_files`
* `sysfile.append_all_chr_files`
* `sysfile.append_all_fifo_files`
* `sysfile.append_all_files`
* `sysfile.appendinherited_all_blk_files`
* `sysfile.appendinherited_all_chr_files`
* `sysfile.appendinherited_all_fifo_files`
* `sysfile.appendinherited_all_files`
* `sysfile.create_all`
* `sysfile.create_all_blk_files`
* `sysfile.create_all_chr_files`
* `sysfile.create_all_dirs`
* `sysfile.create_all_fifo_files`
* `sysfile.create_all_files`
* `sysfile.create_all_lnk_files`
* `sysfile.create_all_sock_files`
* `sysfile.deletename_all_dirs`
* `sysfile.delete_all`
* `sysfile.delete_all_blk_files`
* `sysfile.delete_all_chr_files`
* `sysfile.delete_all_dirs`
* `sysfile.delete_all_fifo_files`
* `sysfile.delete_all_files`
* `sysfile.delete_all_lnk_files`
* `sysfile.delete_all_sock_files`
* `sysfile.execute_all_files`
* `sysfile.getattr_all_files`
* `sysfile.getattr_all_lnk_files`
* `sysfile.list_all_dirs`
* `sysfile.listinherited_all_dirs`
* `sysfile.manage_all`
* `sysfile.manage_all_blk_files`
* `sysfile.manage_all_chr_files`
* `sysfile.manage_all_dirs`
* `sysfile.manage_all_fifo_files`
* `sysfile.manage_all_files`
* `sysfile.manage_all_lnk_files`
* `sysfile.manage_all_sock_files`
* `sysfile.mapexecute_all_chr_files`
* `sysfile.mapexecute_all_files`
* `sysfile.mounton_all`
* `sysfile.mounton_all_blk_files`
* `sysfile.mounton_all_chr_files`
* `sysfile.mounton_all_dirs`
* `sysfile.mounton_all_fifo_files`
* `sysfile.mounton_all_files`
* `sysfile.mounton_all_lnk_files`
* `sysfile.mounton_all_sock_files`
* `sysfile.obj_type`
* `sysfile.read_all`
* `sysfile.read_all_blk_files`
* `sysfile.read_all_chr_files`
* `sysfile.read_all_fifo_files`
* `sysfile.read_all_files`
* `sysfile.read_all_lnk_files`
* `sysfile.read_all_sock_files`
* `sysfile.readinherited_all_blk_files`
* `sysfile.readinherited_all_chr_files`
* `sysfile.readinherited_all_fifo_files`
* `sysfile.readinherited_all_files`
* `sysfile.readinherited_all_sock_files`
* `sysfile.readwrite_all`
* `sysfile.readwrite_all_blk_files`
* `sysfile.readwrite_all_chr_files`
* `sysfile.readwrite_all_dirs`
* `sysfile.readwrite_all_fifo_files`
* `sysfile.readwrite_all_files`
* `sysfile.readwrite_all_lnk_files`
* `sysfile.readwrite_all_sock_files`
* `sysfile.readwriteinherited_all_blk_files`
* `sysfile.readwriteinherited_all_chr_files`
* `sysfile.readwriteinherited_all_dirs`
* `sysfile.readwriteinherited_all_fifo_files`
* `sysfile.readwriteinherited_all_files`
* `sysfile.readwriteinherited_all_sock_files`
* `sysfile.relabel_all`
* `sysfile.relabel_all_blk_files`
* `sysfile.relabel_all_chr_files`
* `sysfile.relabel_all_dirs`
* `sysfile.relabel_all_fifo_files`
* `sysfile.relabel_all_files`
* `sysfile.relabel_all_lnk_files`
* `sysfile.relabel_all_sock_files`
* `sysfile.relabelfrom_all`
* `sysfile.relabelfrom_all_blk_files`
* `sysfile.relabelfrom_all_chr_files`
* `sysfile.relabelfrom_all_dirs`
* `sysfile.relabelfrom_all_fifo_files`
* `sysfile.relabelfrom_all_files`
* `sysfile.relabelfrom_all_lnk_files`
* `sysfile.relabelfrom_all_sock_files`
* `sysfile.relabelto_all`
* `sysfile.relabelto_all_blk_files`
* `sysfile.relabelto_all_chr_files`
* `sysfile.relabelto_all_dirs`
* `sysfile.relabelto_all_fifo_files`
* `sysfile.relabelto_all_files`
* `sysfile.relabelto_all_lnk_files`
* `sysfile.relabelto_all_sock_files`
* `sysfile.rename_all`
* `sysfile.rename_all_blk_files`
* `sysfile.rename_all_chr_files`
* `sysfile.rename_all_dirs`
* `sysfile.rename_all_fifo_files`
* `sysfile.rename_all_files`
* `sysfile.rename_all_lnk_files`
* `sysfile.rename_all_sock_files`
* `sysfile.search_all_dirs`
* `sysfile.write_all`
* `sysfile.write_all_blk_files`
* `sysfile.write_all_chr_files`
* `sysfile.write_all_dirs`
* `sysfile.write_all_fifo_files`
* `sysfile.write_all_files`
* `sysfile.write_all_lnk_files`
* `sysfile.write_all_sock_files`
* `sysfile.writeinherited_all_blk_files`
* `sysfile.writeinherited_all_chr_files`
* `sysfile.writeinherited_all_dirs`
* `sysfile.writeinherited_all_fifo_files`
* `sysfile.writeinherited_all_files`
* `sysfile.writeinherited_all_sock_files`
* `sysfile.dontaudit_manage_all_dirs`
* `sysfile.dontaudit_manage_all_files`
* `sysfile.dontaudit_manage_all_lnk_files`

The `sysfile.obj_base_template` and `sysfile.obj_macro_template` are
inherited at the various equivalent intermediate level "block", "bus",
"class", "dev", "devices", "firmware", "fs", "hypervisor", "kernel",
"module" or "power" object and object base templates.

## src/sysfile/blocksysfile.cil

The `src/sysfile/blocksysfile.cil` module defines Sys files and
access to them at the Block intermediate level namely
"all Sys Block files" and in addition declares a generic Sys Block
file type to be associated with `/sys/block` by default. The Sys Block
context is associated with files using `genfscon` statements.

Available templates:

* `sysfile.block.obj_base_template` Declares a Sys Block file
* `sysfile.block.obj_template` Declares a Sys Block file and includes
macros that provide access to the declared Sys Block file

Macros providing access to `block.sysfile`:

* `block.addname_sysfile_dirs`
* `block.append_sysfile_blk_files`
* `block.append_sysfile_chr_files`
* `block.append_sysfile_fifo_files`
* `block.append_sysfile_files`
* `block.appendinherited_sysfile_blk_files`
* `block.appendinherited_sysfile_chr_files`
* `block.appendinherited_sysfile_fifo_files`
* `block.appendinherited_sysfile_files`
* `block.create_sysfile`
* `block.create_sysfile_blk_files`
* `block.create_sysfile_chr_files`
* `block.create_sysfile_dirs`
* `block.create_sysfile_fifo_files`
* `block.create_sysfile_files`
* `block.create_sysfile_lnk_files`
* `block.create_sysfile_sock_files`
* `block.deletename_sysfile_dirs`
* `block.delete_sysfile`
* `block.delete_sysfile_blk_files`
* `block.delete_sysfile_chr_files`
* `block.delete_sysfile_dirs`
* `block.delete_sysfile_fifo_files`
* `block.delete_sysfile_files`
* `block.delete_sysfile_lnk_files`
* `block.delete_sysfile_sock_files`
* `block.execute_sysfile_files`
* `block.getattr_sysfile_files`
* `block.getattr_sysfile_lnk_files`
* `block.list_sysfile_dirs`
* `block.listinherited_sysfile_dirs`
* `block.manage_sysfile`
* `block.manage_sysfile_blk_files`
* `block.manage_sysfile_chr_files`
* `block.manage_sysfile_dirs`
* `block.manage_sysfile_fifo_files`
* `block.manage_sysfile_files`
* `block.manage_sysfile_lnk_files`
* `block.manage_sysfile_sock_files`
* `block.mapexecute_sysfile_chr_files`
* `block.mapexecute_sysfile_files`
* `block.mounton_sysfile`
* `block.mounton_sysfile_blk_files`
* `block.mounton_sysfile_chr_files`
* `block.mounton_sysfile_dirs`
* `block.mounton_sysfile_fifo_files`
* `block.mounton_sysfile_files`
* `block.mounton_sysfile_lnk_files`
* `block.mounton_sysfile_sock_files`
* `block.read_sysfile`
* `block.read_sysfile_blk_files`
* `block.read_sysfile_chr_files`
* `block.read_sysfile_fifo_files`
* `block.read_sysfile_files`
* `block.read_sysfile_lnk_files`
* `block.read_sysfile_sock_files`
* `block.readinherited_sysfile_blk_files`
* `block.readinherited_sysfile_chr_files`
* `block.readinherited_sysfile_fifo_files`
* `block.readinherited_sysfile_files`
* `block.readinherited_sysfile_sock_files`
* `block.readwrite_sysfile`
* `block.readwrite_sysfile_blk_files`
* `block.readwrite_sysfile_chr_files`
* `block.readwrite_sysfile_dirs`
* `block.readwrite_sysfile_fifo_files`
* `block.readwrite_sysfile_files`
* `block.readwrite_sysfile_lnk_files`
* `block.readwrite_sysfile_sock_files`
* `block.readwriteinherited_sysfile_blk_files`
* `block.readwriteinherited_sysfile_chr_files`
* `block.readwriteinherited_sysfile_dirs`
* `block.readwriteinherited_sysfile_fifo_files`
* `block.readwriteinherited_sysfile_files`
* `block.readwriteinherited_sysfile_sock_files`
* `block.relabel_sysfile`
* `block.relabel_sysfile_blk_files`
* `block.relabel_sysfile_chr_files`
* `block.relabel_sysfile_dirs`
* `block.relabel_sysfile_fifo_files`
* `block.relabel_sysfile_files`
* `block.relabel_sysfile_lnk_files`
* `block.relabel_sysfile_sock_files`
* `block.relabelfrom_sysfile`
* `block.relabelfrom_sysfile_blk_files`
* `block.relabelfrom_sysfile_chr_files`
* `block.relabelfrom_sysfile_dirs`
* `block.relabelfrom_sysfile_fifo_files`
* `block.relabelfrom_sysfile_files`
* `block.relabelfrom_sysfile_lnk_files`
* `block.relabelfrom_sysfile_sock_files`
* `block.relabelto_sysfile`
* `block.relabelto_sysfile_blk_files`
* `block.relabelto_sysfile_chr_files`
* `block.relabelto_sysfile_dirs`
* `block.relabelto_sysfile_fifo_files`
* `block.relabelto_sysfile_files`
* `block.relabelto_sysfile_lnk_files`
* `block.relabelto_sysfile_sock_files`
* `block.rename_sysfile`
* `block.rename_sysfile_blk_files`
* `block.rename_sysfile_chr_files`
* `block.rename_sysfile_dirs`
* `block.rename_sysfile_fifo_files`
* `block.rename_sysfile_files`
* `block.rename_sysfile_lnk_files`
* `block.rename_sysfile_sock_files`
* `block.search_sysfile_dirs`
* `block.sysfile_obj_type_transition`
* `block.write_sysfile`
* `block.write_sysfile_blk_files`
* `block.write_sysfile_chr_files`
* `block.write_sysfile_dirs`
* `block.write_sysfile_fifo_files`
* `block.write_sysfile_files`
* `block.write_sysfile_lnk_files`
* `block.write_sysfile_sock_files`
* `block.writeinherited_sysfile_blk_files`
* `block.writeinherited_sysfile_chr_files`
* `block.writeinherited_sysfile_dirs`
* `block.writeinherited_sysfile_fifo_files`
* `block.writeinherited_sysfile_files`
* `block.writeinherited_sysfile_sock_files`

Macros providing access to `sysfile.block.obj_typeattr`:

* `sysfile.block.addname_all_dirs`
* `sysfile.block.append_all_blk_files`
* `sysfile.block.append_all_chr_files`
* `sysfile.block.append_all_fifo_files`
* `sysfile.block.append_all_files`
* `sysfile.block.appendinherited_all_blk_files`
* `sysfile.block.appendinherited_all_chr_files`
* `sysfile.block.appendinherited_all_fifo_files`
* `sysfile.block.appendinherited_all_files`
* `sysfile.block.create_all`
* `sysfile.block.create_all_blk_files`
* `sysfile.block.create_all_chr_files`
* `sysfile.block.create_all_dirs`
* `sysfile.block.create_all_fifo_files`
* `sysfile.block.create_all_files`
* `sysfile.block.create_all_lnk_files`
* `sysfile.block.create_all_sock_files`
* `sysfile.block.deletename_all_dirs`
* `sysfile.block.delete_all`
* `sysfile.block.delete_all_blk_files`
* `sysfile.block.delete_all_chr_files`
* `sysfile.block.delete_all_dirs`
* `sysfile.block.delete_all_fifo_files`
* `sysfile.block.delete_all_files`
* `sysfile.block.delete_all_lnk_files`
* `sysfile.block.delete_all_sock_files`
* `sysfile.block.execute_all_files`
* `sysfile.block.getattr_all_files`
* `sysfile.block.getattr_all_lnk_files`
* `sysfile.block.list_all_dirs`
* `sysfile.block.listinherited_all_dirs`
* `sysfile.block.manage_all`
* `sysfile.block.manage_all_blk_files`
* `sysfile.block.manage_all_chr_files`
* `sysfile.block.manage_all_dirs`
* `sysfile.block.manage_all_fifo_files`
* `sysfile.block.manage_all_files`
* `sysfile.block.manage_all_lnk_files`
* `sysfile.block.manage_all_sock_files`
* `sysfile.block.mapexecute_all_chr_files`
* `sysfile.block.mapexecute_all_files`
* `sysfile.block.mounton_all`
* `sysfile.block.mounton_all_blk_files`
* `sysfile.block.mounton_all_chr_files`
* `sysfile.block.mounton_all_dirs`
* `sysfile.block.mounton_all_fifo_files`
* `sysfile.block.mounton_all_files`
* `sysfile.block.mounton_all_lnk_files`
* `sysfile.block.mounton_all_sock_files`
* `sysfile.block.obj_type`
* `sysfile.block.read_all`
* `sysfile.block.read_all_blk_files`
* `sysfile.block.read_all_chr_files`
* `sysfile.block.read_all_fifo_files`
* `sysfile.block.read_all_files`
* `sysfile.block.read_all_lnk_files`
* `sysfile.block.read_all_sock_files`
* `sysfile.block.readinherited_all_blk_files`
* `sysfile.block.readinherited_all_chr_files`
* `sysfile.block.readinherited_all_fifo_files`
* `sysfile.block.readinherited_all_files`
* `sysfile.block.readinherited_all_sock_files`
* `sysfile.block.readwrite_all`
* `sysfile.block.readwrite_all_blk_files`
* `sysfile.block.readwrite_all_chr_files`
* `sysfile.block.readwrite_all_dirs`
* `sysfile.block.readwrite_all_fifo_files`
* `sysfile.block.readwrite_all_files`
* `sysfile.block.readwrite_all_lnk_files`
* `sysfile.block.readwrite_all_sock_files`
* `sysfile.block.readwriteinherited_all_blk_files`
* `sysfile.block.readwriteinherited_all_chr_files`
* `sysfile.block.readwriteinherited_all_dirs`
* `sysfile.block.readwriteinherited_all_fifo_files`
* `sysfile.block.readwriteinherited_all_files`
* `sysfile.block.readwriteinherited_all_sock_files`
* `sysfile.block.relabel_all`
* `sysfile.block.relabel_all_blk_files`
* `sysfile.block.relabel_all_chr_files`
* `sysfile.block.relabel_all_dirs`
* `sysfile.block.relabel_all_fifo_files`
* `sysfile.block.relabel_all_files`
* `sysfile.block.relabel_all_lnk_files`
* `sysfile.block.relabel_all_sock_files`
* `sysfile.block.relabelfrom_all`
* `sysfile.block.relabelfrom_all_blk_files`
* `sysfile.block.relabelfrom_all_chr_files`
* `sysfile.block.relabelfrom_all_dirs`
* `sysfile.block.relabelfrom_all_fifo_files`
* `sysfile.block.relabelfrom_all_files`
* `sysfile.block.relabelfrom_all_lnk_files`
* `sysfile.block.relabelfrom_all_sock_files`
* `sysfile.block.relabelto_all`
* `sysfile.block.relabelto_all_blk_files`
* `sysfile.block.relabelto_all_chr_files`
* `sysfile.block.relabelto_all_dirs`
* `sysfile.block.relabelto_all_fifo_files`
* `sysfile.block.relabelto_all_files`
* `sysfile.block.relabelto_all_lnk_files`
* `sysfile.block.relabelto_all_sock_files`
* `sysfile.block.rename_all`
* `sysfile.block.rename_all_blk_files`
* `sysfile.block.rename_all_chr_files`
* `sysfile.block.rename_all_dirs`
* `sysfile.block.rename_all_fifo_files`
* `sysfile.block.rename_all_files`
* `sysfile.block.rename_all_lnk_files`
* `sysfile.block.rename_all_sock_files`
* `sysfile.block.search_all_dirs`
* `sysfile.block.write_all`
* `sysfile.block.write_all_blk_files`
* `sysfile.block.write_all_chr_files`
* `sysfile.block.write_all_dirs`
* `sysfile.block.write_all_fifo_files`
* `sysfile.block.write_all_files`
* `sysfile.block.write_all_lnk_files`
* `sysfile.block.write_all_sock_files`
* `sysfile.block.writeinherited_all_blk_files`
* `sysfile.block.writeinherited_all_chr_files`
* `sysfile.block.writeinherited_all_dirs`
* `sysfile.block.writeinherited_all_fifo_files`
* `sysfile.block.writeinherited_all_files`
* `sysfile.block.writeinherited_all_sock_files`
* `sysfile.block.dontaudit_manage_all_dirs`
* `sysfile.block.dontaudit_manage_all_files`
* `sysfile.block.dontaudit_manage_all_lnk_files`

## src/sysfile/bussysfile.cil

The `src/sysfile/bussysfile.cil` module defines Sys files and
access to them at the Bus intermediate level namely
"all Sys Bus files" and in addition declares a generic Sys Bus
file type to be associated with `/sys/bus` by default. The Sys Bus
context is associated with files using `genfscon` statements.

Available templates:

* `sysfile.bus.obj_base_template` Declares a Sys Bus file
* `sysfile.bus.obj_template` Declares a Sys Bus file and includes macros
that provide access to the declared Sys Bus file

Macros providing access to `bus.sysfile`:

* `bus.addname_sysfile_dirs`
* `bus.append_sysfile_blk_files`
* `bus.append_sysfile_chr_files`
* `bus.append_sysfile_fifo_files`
* `bus.append_sysfile_files`
* `bus.appendinherited_sysfile_blk_files`
* `bus.appendinherited_sysfile_chr_files`
* `bus.appendinherited_sysfile_fifo_files`
* `bus.appendinherited_sysfile_files`
* `bus.create_sysfile`
* `bus.create_sysfile_blk_files`
* `bus.create_sysfile_chr_files`
* `bus.create_sysfile_dirs`
* `bus.create_sysfile_fifo_files`
* `bus.create_sysfile_files`
* `bus.create_sysfile_lnk_files`
* `bus.create_sysfile_sock_files`
* `bus.deletename_sysfile_dirs`
* `bus.delete_sysfile`
* `bus.delete_sysfile_blk_files`
* `bus.delete_sysfile_chr_files`
* `bus.delete_sysfile_dirs`
* `bus.delete_sysfile_fifo_files`
* `bus.delete_sysfile_files`
* `bus.delete_sysfile_lnk_files`
* `bus.delete_sysfile_sock_files`
* `bus.execute_sysfile_files`
* `bus.getattr_sysfile_files`
* `bus.getattr_sysfile_lnk_files`
* `bus.list_sysfile_dirs`
* `bus.listinherited_sysfile_dirs`
* `bus.manage_sysfile`
* `bus.manage_sysfile_blk_files`
* `bus.manage_sysfile_chr_files`
* `bus.manage_sysfile_dirs`
* `bus.manage_sysfile_fifo_files`
* `bus.manage_sysfile_files`
* `bus.manage_sysfile_lnk_files`
* `bus.manage_sysfile_sock_files`
* `bus.mapexecute_sysfile_chr_files`
* `bus.mapexecute_sysfile_files`
* `bus.mounton_sysfile`
* `bus.mounton_sysfile_blk_files`
* `bus.mounton_sysfile_chr_files`
* `bus.mounton_sysfile_dirs`
* `bus.mounton_sysfile_fifo_files`
* `bus.mounton_sysfile_files`
* `bus.mounton_sysfile_lnk_files`
* `bus.mounton_sysfile_sock_files`
* `bus.read_sysfile`
* `bus.read_sysfile_blk_files`
* `bus.read_sysfile_chr_files`
* `bus.read_sysfile_fifo_files`
* `bus.read_sysfile_files`
* `bus.read_sysfile_lnk_files`
* `bus.read_sysfile_sock_files`
* `bus.readinherited_sysfile_blk_files`
* `bus.readinherited_sysfile_chr_files`
* `bus.readinherited_sysfile_fifo_files`
* `bus.readinherited_sysfile_files`
* `bus.readinherited_sysfile_sock_files`
* `bus.readwrite_sysfile`
* `bus.readwrite_sysfile_blk_files`
* `bus.readwrite_sysfile_chr_files`
* `bus.readwrite_sysfile_dirs`
* `bus.readwrite_sysfile_fifo_files`
* `bus.readwrite_sysfile_files`
* `bus.readwrite_sysfile_lnk_files`
* `bus.readwrite_sysfile_sock_files`
* `bus.readwriteinherited_sysfile_blk_files`
* `bus.readwriteinherited_sysfile_chr_files`
* `bus.readwriteinherited_sysfile_dirs`
* `bus.readwriteinherited_sysfile_fifo_files`
* `bus.readwriteinherited_sysfile_files`
* `bus.readwriteinherited_sysfile_sock_files`
* `bus.relabel_sysfile`
* `bus.relabel_sysfile_blk_files`
* `bus.relabel_sysfile_chr_files`
* `bus.relabel_sysfile_dirs`
* `bus.relabel_sysfile_fifo_files`
* `bus.relabel_sysfile_files`
* `bus.relabel_sysfile_lnk_files`
* `bus.relabel_sysfile_sock_files`
* `bus.relabelfrom_sysfile`
* `bus.relabelfrom_sysfile_blk_files`
* `bus.relabelfrom_sysfile_chr_files`
* `bus.relabelfrom_sysfile_dirs`
* `bus.relabelfrom_sysfile_fifo_files`
* `bus.relabelfrom_sysfile_files`
* `bus.relabelfrom_sysfile_lnk_files`
* `bus.relabelfrom_sysfile_sock_files`
* `bus.relabelto_sysfile`
* `bus.relabelto_sysfile_blk_files`
* `bus.relabelto_sysfile_chr_files`
* `bus.relabelto_sysfile_dirs`
* `bus.relabelto_sysfile_fifo_files`
* `bus.relabelto_sysfile_files`
* `bus.relabelto_sysfile_lnk_files`
* `bus.relabelto_sysfile_sock_files`
* `bus.rename_sysfile`
* `bus.rename_sysfile_blk_files`
* `bus.rename_sysfile_chr_files`
* `bus.rename_sysfile_dirs`
* `bus.rename_sysfile_fifo_files`
* `bus.rename_sysfile_files`
* `bus.rename_sysfile_lnk_files`
* `bus.rename_sysfile_sock_files`
* `bus.search_sysfile_dirs`
* `bus.sysfile_obj_type_transition`
* `bus.write_sysfile`
* `bus.write_sysfile_blk_files`
* `bus.write_sysfile_chr_files`
* `bus.write_sysfile_dirs`
* `bus.write_sysfile_fifo_files`
* `bus.write_sysfile_files`
* `bus.write_sysfile_lnk_files`
* `bus.write_sysfile_sock_files`
* `bus.writeinherited_sysfile_blk_files`
* `bus.writeinherited_sysfile_chr_files`
* `bus.writeinherited_sysfile_dirs`
* `bus.writeinherited_sysfile_fifo_files`
* `bus.writeinherited_sysfile_files`
* `bus.writeinherited_sysfile_sock_files`

Macros providing access to `sysfile.bus.obj_typeattr`:

* `sysfile.bus.addname_all_dirs`
* `sysfile.bus.append_all_blk_files`
* `sysfile.bus.append_all_chr_files`
* `sysfile.bus.append_all_fifo_files`
* `sysfile.bus.append_all_files`
* `sysfile.bus.appendinherited_all_blk_files`
* `sysfile.bus.appendinherited_all_chr_files`
* `sysfile.bus.appendinherited_all_fifo_files`
* `sysfile.bus.appendinherited_all_files`
* `sysfile.bus.create_all`
* `sysfile.bus.create_all_blk_files`
* `sysfile.bus.create_all_chr_files`
* `sysfile.bus.create_all_dirs`
* `sysfile.bus.create_all_fifo_files`
* `sysfile.bus.create_all_files`
* `sysfile.bus.create_all_lnk_files`
* `sysfile.bus.create_all_sock_files`
* `sysfile.bus.deletename_all_dirs`
* `sysfile.bus.delete_all`
* `sysfile.bus.delete_all_blk_files`
* `sysfile.bus.delete_all_chr_files`
* `sysfile.bus.delete_all_dirs`
* `sysfile.bus.delete_all_fifo_files`
* `sysfile.bus.delete_all_files`
* `sysfile.bus.delete_all_lnk_files`
* `sysfile.bus.delete_all_sock_files`
* `sysfile.bus.execute_all_files`
* `sysfile.bus.getattr_all_files`
* `sysfile.bus.getattr_all_lnk_files`
* `sysfile.bus.list_all_dirs`
* `sysfile.bus.listinherited_all_dirs`
* `sysfile.bus.manage_all`
* `sysfile.bus.manage_all_blk_files`
* `sysfile.bus.manage_all_chr_files`
* `sysfile.bus.manage_all_dirs`
* `sysfile.bus.manage_all_fifo_files`
* `sysfile.bus.manage_all_files`
* `sysfile.bus.manage_all_lnk_files`
* `sysfile.bus.manage_all_sock_files`
* `sysfile.bus.mapexecute_all_chr_files`
* `sysfile.bus.mapexecute_all_files`
* `sysfile.bus.mounton_all`
* `sysfile.bus.mounton_all_blk_files`
* `sysfile.bus.mounton_all_chr_files`
* `sysfile.bus.mounton_all_dirs`
* `sysfile.bus.mounton_all_fifo_files`
* `sysfile.bus.mounton_all_files`
* `sysfile.bus.mounton_all_lnk_files`
* `sysfile.bus.mounton_all_sock_files`
* `sysfile.bus.obj_type`
* `sysfile.bus.read_all`
* `sysfile.bus.read_all_blk_files`
* `sysfile.bus.read_all_chr_files`
* `sysfile.bus.read_all_fifo_files`
* `sysfile.bus.read_all_files`
* `sysfile.bus.read_all_lnk_files`
* `sysfile.bus.read_all_sock_files`
* `sysfile.bus.readinherited_all_blk_files`
* `sysfile.bus.readinherited_all_chr_files`
* `sysfile.bus.readinherited_all_fifo_files`
* `sysfile.bus.readinherited_all_files`
* `sysfile.bus.readinherited_all_sock_files`
* `sysfile.bus.readwrite_all`
* `sysfile.bus.readwrite_all_blk_files`
* `sysfile.bus.readwrite_all_chr_files`
* `sysfile.bus.readwrite_all_dirs`
* `sysfile.bus.readwrite_all_fifo_files`
* `sysfile.bus.readwrite_all_files`
* `sysfile.bus.readwrite_all_lnk_files`
* `sysfile.bus.readwrite_all_sock_files`
* `sysfile.bus.readwriteinherited_all_blk_files`
* `sysfile.bus.readwriteinherited_all_chr_files`
* `sysfile.bus.readwriteinherited_all_dirs`
* `sysfile.bus.readwriteinherited_all_fifo_files`
* `sysfile.bus.readwriteinherited_all_files`
* `sysfile.bus.readwriteinherited_all_sock_files`
* `sysfile.bus.relabel_all`
* `sysfile.bus.relabel_all_blk_files`
* `sysfile.bus.relabel_all_chr_files`
* `sysfile.bus.relabel_all_dirs`
* `sysfile.bus.relabel_all_fifo_files`
* `sysfile.bus.relabel_all_files`
* `sysfile.bus.relabel_all_lnk_files`
* `sysfile.bus.relabel_all_sock_files`
* `sysfile.bus.relabelfrom_all`
* `sysfile.bus.relabelfrom_all_blk_files`
* `sysfile.bus.relabelfrom_all_chr_files`
* `sysfile.bus.relabelfrom_all_dirs`
* `sysfile.bus.relabelfrom_all_fifo_files`
* `sysfile.bus.relabelfrom_all_files`
* `sysfile.bus.relabelfrom_all_lnk_files`
* `sysfile.bus.relabelfrom_all_sock_files`
* `sysfile.bus.relabelto_all`
* `sysfile.bus.relabelto_all_blk_files`
* `sysfile.bus.relabelto_all_chr_files`
* `sysfile.bus.relabelto_all_dirs`
* `sysfile.bus.relabelto_all_fifo_files`
* `sysfile.bus.relabelto_all_files`
* `sysfile.bus.relabelto_all_lnk_files`
* `sysfile.bus.relabelto_all_sock_files`
* `sysfile.bus.rename_all`
* `sysfile.bus.rename_all_blk_files`
* `sysfile.bus.rename_all_chr_files`
* `sysfile.bus.rename_all_dirs`
* `sysfile.bus.rename_all_fifo_files`
* `sysfile.bus.rename_all_files`
* `sysfile.bus.rename_all_lnk_files`
* `sysfile.bus.rename_all_sock_files`
* `sysfile.bus.search_all_dirs`
* `sysfile.bus.write_all`
* `sysfile.bus.write_all_blk_files`
* `sysfile.bus.write_all_chr_files`
* `sysfile.bus.write_all_dirs`
* `sysfile.bus.write_all_fifo_files`
* `sysfile.bus.write_all_files`
* `sysfile.bus.write_all_lnk_files`
* `sysfile.bus.write_all_sock_files`
* `sysfile.bus.writeinherited_all_blk_files`
* `sysfile.bus.writeinherited_all_chr_files`
* `sysfile.bus.writeinherited_all_dirs`
* `sysfile.bus.writeinherited_all_fifo_files`
* `sysfile.bus.writeinherited_all_files`
* `sysfile.bus.writeinherited_all_sock_files`
* `sysfile.bus.dontaudit_manage_all_dirs`
* `sysfile.bus.dontaudit_manage_all_files`
* `sysfile.bus.dontaudit_manage_all_lnk_files`

## src/sysfile/classsysfile.cil

The `src/sysfile/classsysfile.cil` module defines Sys files and
access to them at the Class intermediate level namely
"all Sys Class files" and in addition declares a generic Sys Class
file type to be associated with `/sys/class` by default. The Sys Class
context is associated with files using `genfscon` statements.

Available templates:

* `sysfile.class.obj_base_template` Declares a Sys Class file
* `sysfile.class.obj_template` Declares a Sys Class file and includes
macros that provide access to the declared Sys Class file

Macros providing access to `class.sysfile`:

* `class.addname_sysfile_dirs`
* `class.append_sysfile_blk_files`
* `class.append_sysfile_chr_files`
* `class.append_sysfile_fifo_files`
* `class.append_sysfile_files`
* `class.appendinherited_sysfile_blk_files`
* `class.appendinherited_sysfile_chr_files`
* `class.appendinherited_sysfile_fifo_files`
* `class.appendinherited_sysfile_files`
* `class.create_sysfile`
* `class.create_sysfile_blk_files`
* `class.create_sysfile_chr_files`
* `class.create_sysfile_dirs`
* `class.create_sysfile_fifo_files`
* `class.create_sysfile_files`
* `class.create_sysfile_lnk_files`
* `class.create_sysfile_sock_files`
* `class.deletename_sysfile_dirs`
* `class.delete_sysfile`
* `class.delete_sysfile_blk_files`
* `class.delete_sysfile_chr_files`
* `class.delete_sysfile_dirs`
* `class.delete_sysfile_fifo_files`
* `class.delete_sysfile_files`
* `class.delete_sysfile_lnk_files`
* `class.delete_sysfile_sock_files`
* `class.execute_sysfile_files`
* `class.getattr_sysfile_files`
* `class.getattr_sysfile_lnk_files`
* `class.list_sysfile_dirs`
* `class.listinherited_sysfile_dirs`
* `class.manage_sysfile`
* `class.manage_sysfile_blk_files`
* `class.manage_sysfile_chr_files`
* `class.manage_sysfile_dirs`
* `class.manage_sysfile_fifo_files`
* `class.manage_sysfile_files`
* `class.manage_sysfile_lnk_files`
* `class.manage_sysfile_sock_files`
* `class.mapexecute_sysfile_chr_files`
* `class.mapexecute_sysfile_files`
* `class.mounton_sysfile`
* `class.mounton_sysfile_blk_files`
* `class.mounton_sysfile_chr_files`
* `class.mounton_sysfile_dirs`
* `class.mounton_sysfile_fifo_files`
* `class.mounton_sysfile_files`
* `class.mounton_sysfile_lnk_files`
* `class.mounton_sysfile_sock_files`
* `class.read_sysfile`
* `class.read_sysfile_blk_files`
* `class.read_sysfile_chr_files`
* `class.read_sysfile_fifo_files`
* `class.read_sysfile_files`
* `class.read_sysfile_lnk_files`
* `class.read_sysfile_sock_files`
* `class.readinherited_sysfile_blk_files`
* `class.readinherited_sysfile_chr_files`
* `class.readinherited_sysfile_fifo_files`
* `class.readinherited_sysfile_files`
* `class.readinherited_sysfile_sock_files`
* `class.readwrite_sysfile`
* `class.readwrite_sysfile_blk_files`
* `class.readwrite_sysfile_chr_files`
* `class.readwrite_sysfile_dirs`
* `class.readwrite_sysfile_fifo_files`
* `class.readwrite_sysfile_files`
* `class.readwrite_sysfile_lnk_files`
* `class.readwrite_sysfile_sock_files`
* `class.readwriteinherited_sysfile_blk_files`
* `class.readwriteinherited_sysfile_chr_files`
* `class.readwriteinherited_sysfile_dirs`
* `class.readwriteinherited_sysfile_fifo_files`
* `class.readwriteinherited_sysfile_files`
* `class.readwriteinherited_sysfile_sock_files`
* `class.relabel_sysfile`
* `class.relabel_sysfile_blk_files`
* `class.relabel_sysfile_chr_files`
* `class.relabel_sysfile_dirs`
* `class.relabel_sysfile_fifo_files`
* `class.relabel_sysfile_files`
* `class.relabel_sysfile_lnk_files`
* `class.relabel_sysfile_sock_files`
* `class.relabelfrom_sysfile`
* `class.relabelfrom_sysfile_blk_files`
* `class.relabelfrom_sysfile_chr_files`
* `class.relabelfrom_sysfile_dirs`
* `class.relabelfrom_sysfile_fifo_files`
* `class.relabelfrom_sysfile_files`
* `class.relabelfrom_sysfile_lnk_files`
* `class.relabelfrom_sysfile_sock_files`
* `class.relabelto_sysfile`
* `class.relabelto_sysfile_blk_files`
* `class.relabelto_sysfile_chr_files`
* `class.relabelto_sysfile_dirs`
* `class.relabelto_sysfile_fifo_files`
* `class.relabelto_sysfile_files`
* `class.relabelto_sysfile_lnk_files`
* `class.relabelto_sysfile_sock_files`
* `class.rename_sysfile`
* `class.rename_sysfile_blk_files`
* `class.rename_sysfile_chr_files`
* `class.rename_sysfile_dirs`
* `class.rename_sysfile_fifo_files`
* `class.rename_sysfile_files`
* `class.rename_sysfile_lnk_files`
* `class.rename_sysfile_sock_files`
* `class.search_sysfile_dirs`
* `class.sysfile_obj_type_transition`
* `class.write_sysfile`
* `class.write_sysfile_blk_files`
* `class.write_sysfile_chr_files`
* `class.write_sysfile_dirs`
* `class.write_sysfile_fifo_files`
* `class.write_sysfile_files`
* `class.write_sysfile_lnk_files`
* `class.write_sysfile_sock_files`
* `class.writeinherited_sysfile_blk_files`
* `class.writeinherited_sysfile_chr_files`
* `class.writeinherited_sysfile_dirs`
* `class.writeinherited_sysfile_fifo_files`
* `class.writeinherited_sysfile_files`
* `class.writeinherited_sysfile_sock_files`

Macros providing access to `sysfile.class.obj_typeattr`:

* `sysfile.class.addname_all_dirs`
* `sysfile.class.append_all_blk_files`
* `sysfile.class.append_all_chr_files`
* `sysfile.class.append_all_fifo_files`
* `sysfile.class.append_all_files`
* `sysfile.class.appendinherited_all_blk_files`
* `sysfile.class.appendinherited_all_chr_files`
* `sysfile.class.appendinherited_all_fifo_files`
* `sysfile.class.appendinherited_all_files`
* `sysfile.class.create_all`
* `sysfile.class.create_all_blk_files`
* `sysfile.class.create_all_chr_files`
* `sysfile.class.create_all_dirs`
* `sysfile.class.create_all_fifo_files`
* `sysfile.class.create_all_files`
* `sysfile.class.create_all_lnk_files`
* `sysfile.class.create_all_sock_files`
* `sysfile.class.deletename_all_dirs`
* `sysfile.class.delete_all`
* `sysfile.class.delete_all_blk_files`
* `sysfile.class.delete_all_chr_files`
* `sysfile.class.delete_all_dirs`
* `sysfile.class.delete_all_fifo_files`
* `sysfile.class.delete_all_files`
* `sysfile.class.delete_all_lnk_files`
* `sysfile.class.delete_all_sock_files`
* `sysfile.class.execute_all_files`
* `sysfile.class.getattr_all_files`
* `sysfile.class.getattr_all_lnk_files`
* `sysfile.class.list_all_dirs`
* `sysfile.class.listinherited_all_dirs`
* `sysfile.class.manage_all`
* `sysfile.class.manage_all_blk_files`
* `sysfile.class.manage_all_chr_files`
* `sysfile.class.manage_all_dirs`
* `sysfile.class.manage_all_fifo_files`
* `sysfile.class.manage_all_files`
* `sysfile.class.manage_all_lnk_files`
* `sysfile.class.manage_all_sock_files`
* `sysfile.class.mapexecute_all_chr_files`
* `sysfile.class.mapexecute_all_files`
* `sysfile.class.mounton_all`
* `sysfile.class.mounton_all_blk_files`
* `sysfile.class.mounton_all_chr_files`
* `sysfile.class.mounton_all_dirs`
* `sysfile.class.mounton_all_fifo_files`
* `sysfile.class.mounton_all_files`
* `sysfile.class.mounton_all_lnk_files`
* `sysfile.class.mounton_all_sock_files`
* `sysfile.class.obj_type`
* `sysfile.class.read_all`
* `sysfile.class.read_all_blk_files`
* `sysfile.class.read_all_chr_files`
* `sysfile.class.read_all_fifo_files`
* `sysfile.class.read_all_files`
* `sysfile.class.read_all_lnk_files`
* `sysfile.class.read_all_sock_files`
* `sysfile.class.readinherited_all_blk_files`
* `sysfile.class.readinherited_all_chr_files`
* `sysfile.class.readinherited_all_fifo_files`
* `sysfile.class.readinherited_all_files`
* `sysfile.class.readinherited_all_sock_files`
* `sysfile.class.readwrite_all`
* `sysfile.class.readwrite_all_blk_files`
* `sysfile.class.readwrite_all_chr_files`
* `sysfile.class.readwrite_all_dirs`
* `sysfile.class.readwrite_all_fifo_files`
* `sysfile.class.readwrite_all_files`
* `sysfile.class.readwrite_all_lnk_files`
* `sysfile.class.readwrite_all_sock_files`
* `sysfile.class.readwriteinherited_all_blk_files`
* `sysfile.class.readwriteinherited_all_chr_files`
* `sysfile.class.readwriteinherited_all_dirs`
* `sysfile.class.readwriteinherited_all_fifo_files`
* `sysfile.class.readwriteinherited_all_files`
* `sysfile.class.readwriteinherited_all_sock_files`
* `sysfile.class.relabel_all`
* `sysfile.class.relabel_all_blk_files`
* `sysfile.class.relabel_all_chr_files`
* `sysfile.class.relabel_all_dirs`
* `sysfile.class.relabel_all_fifo_files`
* `sysfile.class.relabel_all_files`
* `sysfile.class.relabel_all_lnk_files`
* `sysfile.class.relabel_all_sock_files`
* `sysfile.class.relabelfrom_all`
* `sysfile.class.relabelfrom_all_blk_files`
* `sysfile.class.relabelfrom_all_chr_files`
* `sysfile.class.relabelfrom_all_dirs`
* `sysfile.class.relabelfrom_all_fifo_files`
* `sysfile.class.relabelfrom_all_files`
* `sysfile.class.relabelfrom_all_lnk_files`
* `sysfile.class.relabelfrom_all_sock_files`
* `sysfile.class.relabelto_all`
* `sysfile.class.relabelto_all_blk_files`
* `sysfile.class.relabelto_all_chr_files`
* `sysfile.class.relabelto_all_dirs`
* `sysfile.class.relabelto_all_fifo_files`
* `sysfile.class.relabelto_all_files`
* `sysfile.class.relabelto_all_lnk_files`
* `sysfile.class.relabelto_all_sock_files`
* `sysfile.class.rename_all`
* `sysfile.class.rename_all_blk_files`
* `sysfile.class.rename_all_chr_files`
* `sysfile.class.rename_all_dirs`
* `sysfile.class.rename_all_fifo_files`
* `sysfile.class.rename_all_files`
* `sysfile.class.rename_all_lnk_files`
* `sysfile.class.rename_all_sock_files`
* `sysfile.class.search_all_dirs`
* `sysfile.class.write_all`
* `sysfile.class.write_all_blk_files`
* `sysfile.class.write_all_chr_files`
* `sysfile.class.write_all_dirs`
* `sysfile.class.write_all_fifo_files`
* `sysfile.class.write_all_files`
* `sysfile.class.write_all_lnk_files`
* `sysfile.class.write_all_sock_files`
* `sysfile.class.writeinherited_all_blk_files`
* `sysfile.class.writeinherited_all_chr_files`
* `sysfile.class.writeinherited_all_dirs`
* `sysfile.class.writeinherited_all_fifo_files`
* `sysfile.class.writeinherited_all_files`
* `sysfile.class.writeinherited_all_sock_files`
* `sysfile.class.dontaudit_manage_all_dirs`
* `sysfile.class.dontaudit_manage_all_files`
* `sysfile.class.dontaudit_manage_all_lnk_files`

## src/sysfile/devicessysfile.cil

The `src/sysfile/devicessysfile.cil` module defines Sys files and
access to them at the Devices intermediate level namely
"all Sys Devices files" and in addition declares a generic Sys Devices
file type to be associated with `/sys/devices` by default. The Sys
Devices context is associated with files using `genfscon` statements.

Available templates:

* `sysfile.devices.obj_base_template` Declares a Sys Devices file
* `sysfile.devices.obj_template` Declares a Sys Devices file and
includes macros that provide access to the declared Sys Devices file

Macros providing access to `devices.sysfile`:

* `devices.addname_sysfile_dirs`
* `devices.append_sysfile_blk_files`
* `devices.append_sysfile_chr_files`
* `devices.append_sysfile_fifo_files`
* `devices.append_sysfile_files`
* `devices.appendinherited_sysfile_blk_files`
* `devices.appendinherited_sysfile_chr_files`
* `devices.appendinherited_sysfile_fifo_files`
* `devices.appendinherited_sysfile_files`
* `devices.create_sysfile`
* `devices.create_sysfile_blk_files`
* `devices.create_sysfile_chr_files`
* `devices.create_sysfile_dirs`
* `devices.create_sysfile_fifo_files`
* `devices.create_sysfile_files`
* `devices.create_sysfile_lnk_files`
* `devices.create_sysfile_sock_files`
* `devices.deletename_sysfile_dirs`
* `devices.delete_sysfile`
* `devices.delete_sysfile_blk_files`
* `devices.delete_sysfile_chr_files`
* `devices.delete_sysfile_dirs`
* `devices.delete_sysfile_fifo_files`
* `devices.delete_sysfile_files`
* `devices.delete_sysfile_lnk_files`
* `devices.delete_sysfile_sock_files`
* `devices.execute_sysfile_files`
* `devices.getattr_sysfile_files`
* `devices.getattr_sysfile_lnk_files`
* `devices.list_sysfile_dirs`
* `devices.listinherited_sysfile_dirs`
* `devices.manage_sysfile`
* `devices.manage_sysfile_blk_files`
* `devices.manage_sysfile_chr_files`
* `devices.manage_sysfile_dirs`
* `devices.manage_sysfile_fifo_files`
* `devices.manage_sysfile_files`
* `devices.manage_sysfile_lnk_files`
* `devices.manage_sysfile_sock_files`
* `devices.mapexecute_sysfile_chr_files`
* `devices.mapexecute_sysfile_files`
* `devices.mounton_sysfile`
* `devices.mounton_sysfile_blk_files`
* `devices.mounton_sysfile_chr_files`
* `devices.mounton_sysfile_dirs`
* `devices.mounton_sysfile_fifo_files`
* `devices.mounton_sysfile_files`
* `devices.mounton_sysfile_lnk_files`
* `devices.mounton_sysfile_sock_files`
* `devices.read_sysfile`
* `devices.read_sysfile_blk_files`
* `devices.read_sysfile_chr_files`
* `devices.read_sysfile_fifo_files`
* `devices.read_sysfile_files`
* `devices.read_sysfile_lnk_files`
* `devices.read_sysfile_sock_files`
* `devices.readinherited_sysfile_blk_files`
* `devices.readinherited_sysfile_chr_files`
* `devices.readinherited_sysfile_fifo_files`
* `devices.readinherited_sysfile_files`
* `devices.readinherited_sysfile_sock_files`
* `devices.readwrite_sysfile`
* `devices.readwrite_sysfile_blk_files`
* `devices.readwrite_sysfile_chr_files`
* `devices.readwrite_sysfile_dirs`
* `devices.readwrite_sysfile_fifo_files`
* `devices.readwrite_sysfile_files`
* `devices.readwrite_sysfile_lnk_files`
* `devices.readwrite_sysfile_sock_files`
* `devices.readwriteinherited_sysfile_blk_files`
* `devices.readwriteinherited_sysfile_chr_files`
* `devices.readwriteinherited_sysfile_dirs`
* `devices.readwriteinherited_sysfile_fifo_files`
* `devices.readwriteinherited_sysfile_files`
* `devices.readwriteinherited_sysfile_sock_files`
* `devices.relabel_sysfile`
* `devices.relabel_sysfile_blk_files`
* `devices.relabel_sysfile_chr_files`
* `devices.relabel_sysfile_dirs`
* `devices.relabel_sysfile_fifo_files`
* `devices.relabel_sysfile_files`
* `devices.relabel_sysfile_lnk_files`
* `devices.relabel_sysfile_sock_files`
* `devices.relabelfrom_sysfile`
* `devices.relabelfrom_sysfile_blk_files`
* `devices.relabelfrom_sysfile_chr_files`
* `devices.relabelfrom_sysfile_dirs`
* `devices.relabelfrom_sysfile_fifo_files`
* `devices.relabelfrom_sysfile_files`
* `devices.relabelfrom_sysfile_lnk_files`
* `devices.relabelfrom_sysfile_sock_files`
* `devices.relabelto_sysfile`
* `devices.relabelto_sysfile_blk_files`
* `devices.relabelto_sysfile_chr_files`
* `devices.relabelto_sysfile_dirs`
* `devices.relabelto_sysfile_fifo_files`
* `devices.relabelto_sysfile_files`
* `devices.relabelto_sysfile_lnk_files`
* `devices.relabelto_sysfile_sock_files`
* `devices.rename_sysfile`
* `devices.rename_sysfile_blk_files`
* `devices.rename_sysfile_chr_files`
* `devices.rename_sysfile_dirs`
* `devices.rename_sysfile_fifo_files`
* `devices.rename_sysfile_files`
* `devices.rename_sysfile_lnk_files`
* `devices.rename_sysfile_sock_files`
* `devices.search_sysfile_dirs`
* `devices.sysfile_obj_type_transition`
* `devices.write_sysfile`
* `devices.write_sysfile_blk_files`
* `devices.write_sysfile_chr_files`
* `devices.write_sysfile_dirs`
* `devices.write_sysfile_fifo_files`
* `devices.write_sysfile_files`
* `devices.write_sysfile_lnk_files`
* `devices.write_sysfile_sock_files`
* `devices.writeinherited_sysfile_blk_files`
* `devices.writeinherited_sysfile_chr_files`
* `devices.writeinherited_sysfile_dirs`
* `devices.writeinherited_sysfile_fifo_files`
* `devices.writeinherited_sysfile_files`
* `devices.writeinherited_sysfile_sock_files`

Macros providing access to `sysfile.devices.obj_typeattr`:

* `sysfile.devices.addname_all_dirs`
* `sysfile.devices.append_all_blk_files`
* `sysfile.devices.append_all_chr_files`
* `sysfile.devices.append_all_fifo_files`
* `sysfile.devices.append_all_files`
* `sysfile.devices.appendinherited_all_blk_files`
* `sysfile.devices.appendinherited_all_chr_files`
* `sysfile.devices.appendinherited_all_fifo_files`
* `sysfile.devices.appendinherited_all_files`
* `sysfile.devices.create_all`
* `sysfile.devices.create_all_blk_files`
* `sysfile.devices.create_all_chr_files`
* `sysfile.devices.create_all_dirs`
* `sysfile.devices.create_all_fifo_files`
* `sysfile.devices.create_all_files`
* `sysfile.devices.create_all_lnk_files`
* `sysfile.devices.create_all_sock_files`
* `sysfile.devices.deletename_all_dirs`
* `sysfile.devices.delete_all`
* `sysfile.devices.delete_all_blk_files`
* `sysfile.devices.delete_all_chr_files`
* `sysfile.devices.delete_all_dirs`
* `sysfile.devices.delete_all_fifo_files`
* `sysfile.devices.delete_all_files`
* `sysfile.devices.delete_all_lnk_files`
* `sysfile.devices.delete_all_sock_files`
* `sysfile.devices.execute_all_files`
* `sysfile.devices.getattr_all_files`
* `sysfile.devices.getattr_all_lnk_files`
* `sysfile.devices.list_all_dirs`
* `sysfile.devices.listinherited_all_dirs`
* `sysfile.devices.manage_all`
* `sysfile.devices.manage_all_blk_files`
* `sysfile.devices.manage_all_chr_files`
* `sysfile.devices.manage_all_dirs`
* `sysfile.devices.manage_all_fifo_files`
* `sysfile.devices.manage_all_files`
* `sysfile.devices.manage_all_lnk_files`
* `sysfile.devices.manage_all_sock_files`
* `sysfile.devices.mapexecute_all_chr_files`
* `sysfile.devices.mapexecute_all_files`
* `sysfile.devices.mounton_all`
* `sysfile.devices.mounton_all_blk_files`
* `sysfile.devices.mounton_all_chr_files`
* `sysfile.devices.mounton_all_dirs`
* `sysfile.devices.mounton_all_fifo_files`
* `sysfile.devices.mounton_all_files`
* `sysfile.devices.mounton_all_lnk_files`
* `sysfile.devices.mounton_all_sock_files`
* `sysfile.devices.obj_type`
* `sysfile.devices.read_all`
* `sysfile.devices.read_all_blk_files`
* `sysfile.devices.read_all_chr_files`
* `sysfile.devices.read_all_fifo_files`
* `sysfile.devices.read_all_files`
* `sysfile.devices.read_all_lnk_files`
* `sysfile.devices.read_all_sock_files`
* `sysfile.devices.readinherited_all_blk_files`
* `sysfile.devices.readinherited_all_chr_files`
* `sysfile.devices.readinherited_all_fifo_files`
* `sysfile.devices.readinherited_all_files`
* `sysfile.devices.readinherited_all_sock_files`
* `sysfile.devices.readwrite_all`
* `sysfile.devices.readwrite_all_blk_files`
* `sysfile.devices.readwrite_all_chr_files`
* `sysfile.devices.readwrite_all_dirs`
* `sysfile.devices.readwrite_all_fifo_files`
* `sysfile.devices.readwrite_all_files`
* `sysfile.devices.readwrite_all_lnk_files`
* `sysfile.devices.readwrite_all_sock_files`
* `sysfile.devices.readwriteinherited_all_blk_files`
* `sysfile.devices.readwriteinherited_all_chr_files`
* `sysfile.devices.readwriteinherited_all_dirs`
* `sysfile.devices.readwriteinherited_all_fifo_files`
* `sysfile.devices.readwriteinherited_all_files`
* `sysfile.devices.readwriteinherited_all_sock_files`
* `sysfile.devices.relabel_all`
* `sysfile.devices.relabel_all_blk_files`
* `sysfile.devices.relabel_all_chr_files`
* `sysfile.devices.relabel_all_dirs`
* `sysfile.devices.relabel_all_fifo_files`
* `sysfile.devices.relabel_all_files`
* `sysfile.devices.relabel_all_lnk_files`
* `sysfile.devices.relabel_all_sock_files`
* `sysfile.devices.relabelfrom_all`
* `sysfile.devices.relabelfrom_all_blk_files`
* `sysfile.devices.relabelfrom_all_chr_files`
* `sysfile.devices.relabelfrom_all_dirs`
* `sysfile.devices.relabelfrom_all_fifo_files`
* `sysfile.devices.relabelfrom_all_files`
* `sysfile.devices.relabelfrom_all_lnk_files`
* `sysfile.devices.relabelfrom_all_sock_files`
* `sysfile.devices.relabelto_all`
* `sysfile.devices.relabelto_all_blk_files`
* `sysfile.devices.relabelto_all_chr_files`
* `sysfile.devices.relabelto_all_dirs`
* `sysfile.devices.relabelto_all_fifo_files`
* `sysfile.devices.relabelto_all_files`
* `sysfile.devices.relabelto_all_lnk_files`
* `sysfile.devices.relabelto_all_sock_files`
* `sysfile.devices.rename_all`
* `sysfile.devices.rename_all_blk_files`
* `sysfile.devices.rename_all_chr_files`
* `sysfile.devices.rename_all_dirs`
* `sysfile.devices.rename_all_fifo_files`
* `sysfile.devices.rename_all_files`
* `sysfile.devices.rename_all_lnk_files`
* `sysfile.devices.rename_all_sock_files`
* `sysfile.devices.search_all_dirs`
* `sysfile.devices.write_all`
* `sysfile.devices.write_all_blk_files`
* `sysfile.devices.write_all_chr_files`
* `sysfile.devices.write_all_dirs`
* `sysfile.devices.write_all_fifo_files`
* `sysfile.devices.write_all_files`
* `sysfile.devices.write_all_lnk_files`
* `sysfile.devices.write_all_sock_files`
* `sysfile.devices.writeinherited_all_blk_files`
* `sysfile.devices.writeinherited_all_chr_files`
* `sysfile.devices.writeinherited_all_dirs`
* `sysfile.devices.writeinherited_all_fifo_files`
* `sysfile.devices.writeinherited_all_files`
* `sysfile.devices.writeinherited_all_sock_files`
* `sysfile.devices.dontaudit_manage_all_dirs`
* `sysfile.devices.dontaudit_manage_all_files`
* `sysfile.devices.dontaudit_manage_all_lnk_files`

## src/sysfile/devsysfile.cil

The `src/sysfile/devsysfile.cil` module defines Sys files and
access to them at the Dev intermediate level namely
"all Sys Dev files" and in addition declares a generic Sys Dev
file type to be associated with `/sys/dev` by default. The Sys Dev
context is associated with files using `genfscon` statements.

Available templates:

* `sysfile.dev.obj_base_template` Declares a Sys Dev file
* `sysfile.dev.obj_template` Declares a Sys Dev file and includes
macros that provide access to the declared Sys Dev file

Macros providing access to `dev.sysfile`:

* `dev.addname_sysfile_dirs`
* `dev.append_sysfile_blk_files`
* `dev.append_sysfile_chr_files`
* `dev.append_sysfile_fifo_files`
* `dev.append_sysfile_files`
* `dev.appendinherited_sysfile_blk_files`
* `dev.appendinherited_sysfile_chr_files`
* `dev.appendinherited_sysfile_fifo_files`
* `dev.appendinherited_sysfile_files`
* `dev.create_sysfile`
* `dev.create_sysfile_blk_files`
* `dev.create_sysfile_chr_files`
* `dev.create_sysfile_dirs`
* `dev.create_sysfile_fifo_files`
* `dev.create_sysfile_files`
* `dev.create_sysfile_lnk_files`
* `dev.create_sysfile_sock_files`
* `dev.deletename_sysfile_dirs`
* `dev.delete_sysfile`
* `dev.delete_sysfile_blk_files`
* `dev.delete_sysfile_chr_files`
* `dev.delete_sysfile_dirs`
* `dev.delete_sysfile_fifo_files`
* `dev.delete_sysfile_files`
* `dev.delete_sysfile_lnk_files`
* `dev.delete_sysfile_sock_files`
* `dev.execute_sysfile_files`
* `dev.getattr_sysfile_files`
* `dev.getattr_sysfile_lnk_files`
* `dev.list_sysfile_dirs`
* `dev.listinherited_sysfile_dirs`
* `dev.manage_sysfile`
* `dev.manage_sysfile_blk_files`
* `dev.manage_sysfile_chr_files`
* `dev.manage_sysfile_dirs`
* `dev.manage_sysfile_fifo_files`
* `dev.manage_sysfile_files`
* `dev.manage_sysfile_lnk_files`
* `dev.manage_sysfile_sock_files`
* `dev.mapexecute_sysfile_chr_files`
* `dev.mapexecute_sysfile_files`
* `dev.mounton_sysfile`
* `dev.mounton_sysfile_blk_files`
* `dev.mounton_sysfile_chr_files`
* `dev.mounton_sysfile_dirs`
* `dev.mounton_sysfile_fifo_files`
* `dev.mounton_sysfile_files`
* `dev.mounton_sysfile_lnk_files`
* `dev.mounton_sysfile_sock_files`
* `dev.read_sysfile`
* `dev.read_sysfile_blk_files`
* `dev.read_sysfile_chr_files`
* `dev.read_sysfile_fifo_files`
* `dev.read_sysfile_files`
* `dev.read_sysfile_lnk_files`
* `dev.read_sysfile_sock_files`
* `dev.readinherited_sysfile_blk_files`
* `dev.readinherited_sysfile_chr_files`
* `dev.readinherited_sysfile_fifo_files`
* `dev.readinherited_sysfile_files`
* `dev.readinherited_sysfile_sock_files`
* `dev.readwrite_sysfile`
* `dev.readwrite_sysfile_blk_files`
* `dev.readwrite_sysfile_chr_files`
* `dev.readwrite_sysfile_dirs`
* `dev.readwrite_sysfile_fifo_files`
* `dev.readwrite_sysfile_files`
* `dev.readwrite_sysfile_lnk_files`
* `dev.readwrite_sysfile_sock_files`
* `dev.readwriteinherited_sysfile_blk_files`
* `dev.readwriteinherited_sysfile_chr_files`
* `dev.readwriteinherited_sysfile_dirs`
* `dev.readwriteinherited_sysfile_fifo_files`
* `dev.readwriteinherited_sysfile_files`
* `dev.readwriteinherited_sysfile_sock_files`
* `dev.relabel_sysfile`
* `dev.relabel_sysfile_blk_files`
* `dev.relabel_sysfile_chr_files`
* `dev.relabel_sysfile_dirs`
* `dev.relabel_sysfile_fifo_files`
* `dev.relabel_sysfile_files`
* `dev.relabel_sysfile_lnk_files`
* `dev.relabel_sysfile_sock_files`
* `dev.relabelfrom_sysfile`
* `dev.relabelfrom_sysfile_blk_files`
* `dev.relabelfrom_sysfile_chr_files`
* `dev.relabelfrom_sysfile_dirs`
* `dev.relabelfrom_sysfile_fifo_files`
* `dev.relabelfrom_sysfile_files`
* `dev.relabelfrom_sysfile_lnk_files`
* `dev.relabelfrom_sysfile_sock_files`
* `dev.relabelto_sysfile`
* `dev.relabelto_sysfile_blk_files`
* `dev.relabelto_sysfile_chr_files`
* `dev.relabelto_sysfile_dirs`
* `dev.relabelto_sysfile_fifo_files`
* `dev.relabelto_sysfile_files`
* `dev.relabelto_sysfile_lnk_files`
* `dev.relabelto_sysfile_sock_files`
* `dev.rename_sysfile`
* `dev.rename_sysfile_blk_files`
* `dev.rename_sysfile_chr_files`
* `dev.rename_sysfile_dirs`
* `dev.rename_sysfile_fifo_files`
* `dev.rename_sysfile_files`
* `dev.rename_sysfile_lnk_files`
* `dev.rename_sysfile_sock_files`
* `dev.search_sysfile_dirs`
* `dev.sysfile_obj_type_transition`
* `dev.write_sysfile`
* `dev.write_sysfile_blk_files`
* `dev.write_sysfile_chr_files`
* `dev.write_sysfile_dirs`
* `dev.write_sysfile_fifo_files`
* `dev.write_sysfile_files`
* `dev.write_sysfile_lnk_files`
* `dev.write_sysfile_sock_files`
* `dev.writeinherited_sysfile_blk_files`
* `dev.writeinherited_sysfile_chr_files`
* `dev.writeinherited_sysfile_dirs`
* `dev.writeinherited_sysfile_fifo_files`
* `dev.writeinherited_sysfile_files`
* `dev.writeinherited_sysfile_sock_files`

Macros providing access to `sysfile.dev.obj_typeattr`:

* `sysfile.dev.addname_all_dirs`
* `sysfile.dev.append_all_blk_files`
* `sysfile.dev.append_all_chr_files`
* `sysfile.dev.append_all_fifo_files`
* `sysfile.dev.append_all_files`
* `sysfile.dev.appendinherited_all_blk_files`
* `sysfile.dev.appendinherited_all_chr_files`
* `sysfile.dev.appendinherited_all_fifo_files`
* `sysfile.dev.appendinherited_all_files`
* `sysfile.dev.create_all`
* `sysfile.dev.create_all_blk_files`
* `sysfile.dev.create_all_chr_files`
* `sysfile.dev.create_all_dirs`
* `sysfile.dev.create_all_fifo_files`
* `sysfile.dev.create_all_files`
* `sysfile.dev.create_all_lnk_files`
* `sysfile.dev.create_all_sock_files`
* `sysfile.dev.deletename_all_dirs`
* `sysfile.dev.delete_all`
* `sysfile.dev.delete_all_blk_files`
* `sysfile.dev.delete_all_chr_files`
* `sysfile.dev.delete_all_dirs`
* `sysfile.dev.delete_all_fifo_files`
* `sysfile.dev.delete_all_files`
* `sysfile.dev.delete_all_lnk_files`
* `sysfile.dev.delete_all_sock_files`
* `sysfile.dev.execute_all_files`
* `sysfile.dev.getattr_all_files`
* `sysfile.dev.getattr_all_lnk_files`
* `sysfile.dev.list_all_dirs`
* `sysfile.dev.listinherited_all_dirs`
* `sysfile.dev.manage_all`
* `sysfile.dev.manage_all_blk_files`
* `sysfile.dev.manage_all_chr_files`
* `sysfile.dev.manage_all_dirs`
* `sysfile.dev.manage_all_fifo_files`
* `sysfile.dev.manage_all_files`
* `sysfile.dev.manage_all_lnk_files`
* `sysfile.dev.manage_all_sock_files`
* `sysfile.dev.mapexecute_all_chr_files`
* `sysfile.dev.mapexecute_all_files`
* `sysfile.dev.mounton_all`
* `sysfile.dev.mounton_all_blk_files`
* `sysfile.dev.mounton_all_chr_files`
* `sysfile.dev.mounton_all_dirs`
* `sysfile.dev.mounton_all_fifo_files`
* `sysfile.dev.mounton_all_files`
* `sysfile.dev.mounton_all_lnk_files`
* `sysfile.dev.mounton_all_sock_files`
* `sysfile.dev.obj_type`
* `sysfile.dev.read_all`
* `sysfile.dev.read_all_blk_files`
* `sysfile.dev.read_all_chr_files`
* `sysfile.dev.read_all_fifo_files`
* `sysfile.dev.read_all_files`
* `sysfile.dev.read_all_lnk_files`
* `sysfile.dev.read_all_sock_files`
* `sysfile.dev.readinherited_all_blk_files`
* `sysfile.dev.readinherited_all_chr_files`
* `sysfile.dev.readinherited_all_fifo_files`
* `sysfile.dev.readinherited_all_files`
* `sysfile.dev.readinherited_all_sock_files`
* `sysfile.dev.readwrite_all`
* `sysfile.dev.readwrite_all_blk_files`
* `sysfile.dev.readwrite_all_chr_files`
* `sysfile.dev.readwrite_all_dirs`
* `sysfile.dev.readwrite_all_fifo_files`
* `sysfile.dev.readwrite_all_files`
* `sysfile.dev.readwrite_all_lnk_files`
* `sysfile.dev.readwrite_all_sock_files`
* `sysfile.dev.readwriteinherited_all_blk_files`
* `sysfile.dev.readwriteinherited_all_chr_files`
* `sysfile.dev.readwriteinherited_all_dirs`
* `sysfile.dev.readwriteinherited_all_fifo_files`
* `sysfile.dev.readwriteinherited_all_files`
* `sysfile.dev.readwriteinherited_all_sock_files`
* `sysfile.dev.relabel_all`
* `sysfile.dev.relabel_all_blk_files`
* `sysfile.dev.relabel_all_chr_files`
* `sysfile.dev.relabel_all_dirs`
* `sysfile.dev.relabel_all_fifo_files`
* `sysfile.dev.relabel_all_files`
* `sysfile.dev.relabel_all_lnk_files`
* `sysfile.dev.relabel_all_sock_files`
* `sysfile.dev.relabelfrom_all`
* `sysfile.dev.relabelfrom_all_blk_files`
* `sysfile.dev.relabelfrom_all_chr_files`
* `sysfile.dev.relabelfrom_all_dirs`
* `sysfile.dev.relabelfrom_all_fifo_files`
* `sysfile.dev.relabelfrom_all_files`
* `sysfile.dev.relabelfrom_all_lnk_files`
* `sysfile.dev.relabelfrom_all_sock_files`
* `sysfile.dev.relabelto_all`
* `sysfile.dev.relabelto_all_blk_files`
* `sysfile.dev.relabelto_all_chr_files`
* `sysfile.dev.relabelto_all_dirs`
* `sysfile.dev.relabelto_all_fifo_files`
* `sysfile.dev.relabelto_all_files`
* `sysfile.dev.relabelto_all_lnk_files`
* `sysfile.dev.relabelto_all_sock_files`
* `sysfile.dev.rename_all`
* `sysfile.dev.rename_all_blk_files`
* `sysfile.dev.rename_all_chr_files`
* `sysfile.dev.rename_all_dirs`
* `sysfile.dev.rename_all_fifo_files`
* `sysfile.dev.rename_all_files`
* `sysfile.dev.rename_all_lnk_files`
* `sysfile.dev.rename_all_sock_files`
* `sysfile.dev.search_all_dirs`
* `sysfile.dev.write_all`
* `sysfile.dev.write_all_blk_files`
* `sysfile.dev.write_all_chr_files`
* `sysfile.dev.write_all_dirs`
* `sysfile.dev.write_all_fifo_files`
* `sysfile.dev.write_all_files`
* `sysfile.dev.write_all_lnk_files`
* `sysfile.dev.write_all_sock_files`
* `sysfile.dev.writeinherited_all_blk_files`
* `sysfile.dev.writeinherited_all_chr_files`
* `sysfile.dev.writeinherited_all_dirs`
* `sysfile.dev.writeinherited_all_fifo_files`
* `sysfile.dev.writeinherited_all_files`
* `sysfile.dev.writeinherited_all_sock_files`
* `sysfile.dev.dontaudit_manage_all_dirs`
* `sysfile.dev.dontaudit_manage_all_files`
* `sysfile.dev.dontaudit_manage_all_lnk_files`

## src/sysfile/firmwaresysfile.cil

The `src/sysfile/firmwaresysfile.cil` module defines Sys files and
access to them at the Firmware intermediate level namely
"all Sys Firmware files" and in addition declares a generic Sys
Firmware file type to be associated with `/sys/firmware` by default.
The Sys firmware context is associated with files using `genfscon`
statements.

Available templates:

* `sysfile.firmware.obj_base_template` Declares a Sys Firmware file
* `sysfile.firmware.obj_template` Declares a Sys firmware file and
includes macros that provide access to the declared Sys Firmware file

Macros providing access to `firmware.sysfile`:

* `firmware.addname_sysfile_dirs`
* `firmware.append_sysfile_blk_files`
* `firmware.append_sysfile_chr_files`
* `firmware.append_sysfile_fifo_files`
* `firmware.append_sysfile_files`
* `firmware.appendinherited_sysfile_blk_files`
* `firmware.appendinherited_sysfile_chr_files`
* `firmware.appendinherited_sysfile_fifo_files`
* `firmware.appendinherited_sysfile_files`
* `firmware.create_sysfile`
* `firmware.create_sysfile_blk_files`
* `firmware.create_sysfile_chr_files`
* `firmware.create_sysfile_dirs`
* `firmware.create_sysfile_fifo_files`
* `firmware.create_sysfile_files`
* `firmware.create_sysfile_lnk_files`
* `firmware.create_sysfile_sock_files`
* `firmware.deletename_sysfile_dirs`
* `firmware.delete_sysfile`
* `firmware.delete_sysfile_blk_files`
* `firmware.delete_sysfile_chr_files`
* `firmware.delete_sysfile_dirs`
* `firmware.delete_sysfile_fifo_files`
* `firmware.delete_sysfile_files`
* `firmware.delete_sysfile_lnk_files`
* `firmware.delete_sysfile_sock_files`
* `firmware.execute_sysfile_files`
* `firmware.getattr_sysfile_files`
* `firmware.getattr_sysfile_lnk_files`
* `firmware.list_sysfile_dirs`
* `firmware.listinherited_sysfile_dirs`
* `firmware.manage_sysfile`
* `firmware.manage_sysfile_blk_files`
* `firmware.manage_sysfile_chr_files`
* `firmware.manage_sysfile_dirs`
* `firmware.manage_sysfile_fifo_files`
* `firmware.manage_sysfile_files`
* `firmware.manage_sysfile_lnk_files`
* `firmware.manage_sysfile_sock_files`
* `firmware.mapexecute_sysfile_chr_files`
* `firmware.mapexecute_sysfile_files`
* `firmware.mounton_sysfile`
* `firmware.mounton_sysfile_blk_files`
* `firmware.mounton_sysfile_chr_files`
* `firmware.mounton_sysfile_dirs`
* `firmware.mounton_sysfile_fifo_files`
* `firmware.mounton_sysfile_files`
* `firmware.mounton_sysfile_lnk_files`
* `firmware.mounton_sysfile_sock_files`
* `firmware.read_sysfile`
* `firmware.read_sysfile_blk_files`
* `firmware.read_sysfile_chr_files`
* `firmware.read_sysfile_fifo_files`
* `firmware.read_sysfile_files`
* `firmware.read_sysfile_lnk_files`
* `firmware.read_sysfile_sock_files`
* `firmware.readinherited_sysfile_blk_files`
* `firmware.readinherited_sysfile_chr_files`
* `firmware.readinherited_sysfile_fifo_files`
* `firmware.readinherited_sysfile_files`
* `firmware.readinherited_sysfile_sock_files`
* `firmware.readwrite_sysfile`
* `firmware.readwrite_sysfile_blk_files`
* `firmware.readwrite_sysfile_chr_files`
* `firmware.readwrite_sysfile_dirs`
* `firmware.readwrite_sysfile_fifo_files`
* `firmware.readwrite_sysfile_files`
* `firmware.readwrite_sysfile_lnk_files`
* `firmware.readwrite_sysfile_sock_files`
* `firmware.readwriteinherited_sysfile_blk_files`
* `firmware.readwriteinherited_sysfile_chr_files`
* `firmware.readwriteinherited_sysfile_dirs`
* `firmware.readwriteinherited_sysfile_fifo_files`
* `firmware.readwriteinherited_sysfile_files`
* `firmware.readwriteinherited_sysfile_sock_files`
* `firmware.relabel_sysfile`
* `firmware.relabel_sysfile_blk_files`
* `firmware.relabel_sysfile_chr_files`
* `firmware.relabel_sysfile_dirs`
* `firmware.relabel_sysfile_fifo_files`
* `firmware.relabel_sysfile_files`
* `firmware.relabel_sysfile_lnk_files`
* `firmware.relabel_sysfile_sock_files`
* `firmware.relabelfrom_sysfile`
* `firmware.relabelfrom_sysfile_blk_files`
* `firmware.relabelfrom_sysfile_chr_files`
* `firmware.relabelfrom_sysfile_dirs`
* `firmware.relabelfrom_sysfile_fifo_files`
* `firmware.relabelfrom_sysfile_files`
* `firmware.relabelfrom_sysfile_lnk_files`
* `firmware.relabelfrom_sysfile_sock_files`
* `firmware.relabelto_sysfile`
* `firmware.relabelto_sysfile_blk_files`
* `firmware.relabelto_sysfile_chr_files`
* `firmware.relabelto_sysfile_dirs`
* `firmware.relabelto_sysfile_fifo_files`
* `firmware.relabelto_sysfile_files`
* `firmware.relabelto_sysfile_lnk_files`
* `firmware.relabelto_sysfile_sock_files`
* `firmware.rename_sysfile`
* `firmware.rename_sysfile_blk_files`
* `firmware.rename_sysfile_chr_files`
* `firmware.rename_sysfile_dirs`
* `firmware.rename_sysfile_fifo_files`
* `firmware.rename_sysfile_files`
* `firmware.rename_sysfile_lnk_files`
* `firmware.rename_sysfile_sock_files`
* `firmware.search_sysfile_dirs`
* `firmware.sysfile_obj_type_transition`
* `firmware.write_sysfile`
* `firmware.write_sysfile_blk_files`
* `firmware.write_sysfile_chr_files`
* `firmware.write_sysfile_dirs`
* `firmware.write_sysfile_fifo_files`
* `firmware.write_sysfile_files`
* `firmware.write_sysfile_lnk_files`
* `firmware.write_sysfile_sock_files`
* `firmware.writeinherited_sysfile_blk_files`
* `firmware.writeinherited_sysfile_chr_files`
* `firmware.writeinherited_sysfile_dirs`
* `firmware.writeinherited_sysfile_fifo_files`
* `firmware.writeinherited_sysfile_files`
* `firmware.writeinherited_sysfile_sock_files`

Macros providing access to `sysfile.firmware.obj_typeattr`:

* `sysfile.firmware.addname_all_dirs`
* `sysfile.firmware.append_all_blk_files`
* `sysfile.firmware.append_all_chr_files`
* `sysfile.firmware.append_all_fifo_files`
* `sysfile.firmware.append_all_files`
* `sysfile.firmware.appendinherited_all_blk_files`
* `sysfile.firmware.appendinherited_all_chr_files`
* `sysfile.firmware.appendinherited_all_fifo_files`
* `sysfile.firmware.appendinherited_all_files`
* `sysfile.firmware.create_all`
* `sysfile.firmware.create_all_blk_files`
* `sysfile.firmware.create_all_chr_files`
* `sysfile.firmware.create_all_dirs`
* `sysfile.firmware.create_all_fifo_files`
* `sysfile.firmware.create_all_files`
* `sysfile.firmware.create_all_lnk_files`
* `sysfile.firmware.create_all_sock_files`
* `sysfile.firmware.deletename_all_dirs`
* `sysfile.firmware.delete_all`
* `sysfile.firmware.delete_all_blk_files`
* `sysfile.firmware.delete_all_chr_files`
* `sysfile.firmware.delete_all_dirs`
* `sysfile.firmware.delete_all_fifo_files`
* `sysfile.firmware.delete_all_files`
* `sysfile.firmware.delete_all_lnk_files`
* `sysfile.firmware.delete_all_sock_files`
* `sysfile.firmware.execute_all_files`
* `sysfile.firmware.getattr_all_files`
* `sysfile.firmware.getattr_all_lnk_files`
* `sysfile.firmware.list_all_dirs`
* `sysfile.firmware.listinherited_all_dirs`
* `sysfile.firmware.manage_all`
* `sysfile.firmware.manage_all_blk_files`
* `sysfile.firmware.manage_all_chr_files`
* `sysfile.firmware.manage_all_dirs`
* `sysfile.firmware.manage_all_fifo_files`
* `sysfile.firmware.manage_all_files`
* `sysfile.firmware.manage_all_lnk_files`
* `sysfile.firmware.manage_all_sock_files`
* `sysfile.firmware.mapexecute_all_chr_files`
* `sysfile.firmware.mapexecute_all_files`
* `sysfile.firmware.mounton_all`
* `sysfile.firmware.mounton_all_blk_files`
* `sysfile.firmware.mounton_all_chr_files`
* `sysfile.firmware.mounton_all_dirs`
* `sysfile.firmware.mounton_all_fifo_files`
* `sysfile.firmware.mounton_all_files`
* `sysfile.firmware.mounton_all_lnk_files`
* `sysfile.firmware.mounton_all_sock_files`
* `sysfile.firmware.obj_type`
* `sysfile.firmware.read_all`
* `sysfile.firmware.read_all_blk_files`
* `sysfile.firmware.read_all_chr_files`
* `sysfile.firmware.read_all_fifo_files`
* `sysfile.firmware.read_all_files`
* `sysfile.firmware.read_all_lnk_files`
* `sysfile.firmware.read_all_sock_files`
* `sysfile.firmware.readinherited_all_blk_files`
* `sysfile.firmware.readinherited_all_chr_files`
* `sysfile.firmware.readinherited_all_fifo_files`
* `sysfile.firmware.readinherited_all_files`
* `sysfile.firmware.readinherited_all_sock_files`
* `sysfile.firmware.readwrite_all`
* `sysfile.firmware.readwrite_all_blk_files`
* `sysfile.firmware.readwrite_all_chr_files`
* `sysfile.firmware.readwrite_all_dirs`
* `sysfile.firmware.readwrite_all_fifo_files`
* `sysfile.firmware.readwrite_all_files`
* `sysfile.firmware.readwrite_all_lnk_files`
* `sysfile.firmware.readwrite_all_sock_files`
* `sysfile.firmware.readwriteinherited_all_blk_files`
* `sysfile.firmware.readwriteinherited_all_chr_files`
* `sysfile.firmware.readwriteinherited_all_dirs`
* `sysfile.firmware.readwriteinherited_all_fifo_files`
* `sysfile.firmware.readwriteinherited_all_files`
* `sysfile.firmware.readwriteinherited_all_sock_files`
* `sysfile.firmware.relabel_all`
* `sysfile.firmware.relabel_all_blk_files`
* `sysfile.firmware.relabel_all_chr_files`
* `sysfile.firmware.relabel_all_dirs`
* `sysfile.firmware.relabel_all_fifo_files`
* `sysfile.firmware.relabel_all_files`
* `sysfile.firmware.relabel_all_lnk_files`
* `sysfile.firmware.relabel_all_sock_files`
* `sysfile.firmware.relabelfrom_all`
* `sysfile.firmware.relabelfrom_all_blk_files`
* `sysfile.firmware.relabelfrom_all_chr_files`
* `sysfile.firmware.relabelfrom_all_dirs`
* `sysfile.firmware.relabelfrom_all_fifo_files`
* `sysfile.firmware.relabelfrom_all_files`
* `sysfile.firmware.relabelfrom_all_lnk_files`
* `sysfile.firmware.relabelfrom_all_sock_files`
* `sysfile.firmware.relabelto_all`
* `sysfile.firmware.relabelto_all_blk_files`
* `sysfile.firmware.relabelto_all_chr_files`
* `sysfile.firmware.relabelto_all_dirs`
* `sysfile.firmware.relabelto_all_fifo_files`
* `sysfile.firmware.relabelto_all_files`
* `sysfile.firmware.relabelto_all_lnk_files`
* `sysfile.firmware.relabelto_all_sock_files`
* `sysfile.firmware.rename_all`
* `sysfile.firmware.rename_all_blk_files`
* `sysfile.firmware.rename_all_chr_files`
* `sysfile.firmware.rename_all_dirs`
* `sysfile.firmware.rename_all_fifo_files`
* `sysfile.firmware.rename_all_files`
* `sysfile.firmware.rename_all_lnk_files`
* `sysfile.firmware.rename_all_sock_files`
* `sysfile.firmware.search_all_dirs`
* `sysfile.firmware.write_all`
* `sysfile.firmware.write_all_blk_files`
* `sysfile.firmware.write_all_chr_files`
* `sysfile.firmware.write_all_dirs`
* `sysfile.firmware.write_all_fifo_files`
* `sysfile.firmware.write_all_files`
* `sysfile.firmware.write_all_lnk_files`
* `sysfile.firmware.write_all_sock_files`
* `sysfile.firmware.writeinherited_all_blk_files`
* `sysfile.firmware.writeinherited_all_chr_files`
* `sysfile.firmware.writeinherited_all_dirs`
* `sysfile.firmware.writeinherited_all_fifo_files`
* `sysfile.firmware.writeinherited_all_files`
* `sysfile.firmware.writeinherited_all_sock_files`
* `sysfile.firmware.dontaudit_manage_all_dirs`
* `sysfile.firmware.dontaudit_manage_all_files`
* `sysfile.firmware.dontaudit_manage_all_lnk_files`

## src/sysfile/fssysfile.cil

The `src/sysfile/fssysfile.cil` module defines Sys files and
access to them at the FS intermediate level namely
"all Sys FS files" and in addition declares a generic Sys FS
file type to be associated with `/sys/fs` by default. The Sys FS
context is associated with files using `genfscon` statements.

Available templates:

* `sysfile.fs.obj_base_template` Declares a Sys FS file
* `sysfile.fs.obj_template` Declares a Sys FS file and includes
macros that provide access to the declared Sys FS file

Macros providing access to `fs.sysfile`:

* `fs.addname_sysfile_dirs`
* `fs.append_sysfile_blk_files`
* `fs.append_sysfile_chr_files`
* `fs.append_sysfile_fifo_files`
* `fs.append_sysfile_files`
* `fs.appendinherited_sysfile_blk_files`
* `fs.appendinherited_sysfile_chr_files`
* `fs.appendinherited_sysfile_fifo_files`
* `fs.appendinherited_sysfile_files`
* `fs.create_sysfile`
* `fs.create_sysfile_blk_files`
* `fs.create_sysfile_chr_files`
* `fs.create_sysfile_dirs`
* `fs.create_sysfile_fifo_files`
* `fs.create_sysfile_files`
* `fs.create_sysfile_lnk_files`
* `fs.create_sysfile_sock_files`
* `fs.deletename_sysfile_dirs`
* `fs.delete_sysfile`
* `fs.delete_sysfile_blk_files`
* `fs.delete_sysfile_chr_files`
* `fs.delete_sysfile_dirs`
* `fs.delete_sysfile_fifo_files`
* `fs.delete_sysfile_files`
* `fs.delete_sysfile_lnk_files`
* `fs.delete_sysfile_sock_files`
* `fs.execute_sysfile_files`
* `fs.getattr_sysfile_files`
* `fs.getattr_sysfile_lnk_files`
* `fs.list_sysfile_dirs`
* `fs.listinherited_sysfile_dirs`
* `fs.manage_sysfile`
* `fs.manage_sysfile_blk_files`
* `fs.manage_sysfile_chr_files`
* `fs.manage_sysfile_dirs`
* `fs.manage_sysfile_fifo_files`
* `fs.manage_sysfile_files`
* `fs.manage_sysfile_lnk_files`
* `fs.manage_sysfile_sock_files`
* `fs.mapexecute_sysfile_chr_files`
* `fs.mapexecute_sysfile_files`
* `fs.mounton_sysfile`
* `fs.mounton_sysfile_blk_files`
* `fs.mounton_sysfile_chr_files`
* `fs.mounton_sysfile_dirs`
* `fs.mounton_sysfile_fifo_files`
* `fs.mounton_sysfile_files`
* `fs.mounton_sysfile_lnk_files`
* `fs.mounton_sysfile_sock_files`
* `fs.read_sysfile`
* `fs.read_sysfile_blk_files`
* `fs.read_sysfile_chr_files`
* `fs.read_sysfile_fifo_files`
* `fs.read_sysfile_files`
* `fs.read_sysfile_lnk_files`
* `fs.read_sysfile_sock_files`
* `fs.readinherited_sysfile_blk_files`
* `fs.readinherited_sysfile_chr_files`
* `fs.readinherited_sysfile_fifo_files`
* `fs.readinherited_sysfile_files`
* `fs.readinherited_sysfile_sock_files`
* `fs.readwrite_sysfile`
* `fs.readwrite_sysfile_blk_files`
* `fs.readwrite_sysfile_chr_files`
* `fs.readwrite_sysfile_dirs`
* `fs.readwrite_sysfile_fifo_files`
* `fs.readwrite_sysfile_files`
* `fs.readwrite_sysfile_lnk_files`
* `fs.readwrite_sysfile_sock_files`
* `fs.readwriteinherited_sysfile_blk_files`
* `fs.readwriteinherited_sysfile_chr_files`
* `fs.readwriteinherited_sysfile_dirs`
* `fs.readwriteinherited_sysfile_fifo_files`
* `fs.readwriteinherited_sysfile_files`
* `fs.readwriteinherited_sysfile_sock_files`
* `fs.relabel_sysfile`
* `fs.relabel_sysfile_blk_files`
* `fs.relabel_sysfile_chr_files`
* `fs.relabel_sysfile_dirs`
* `fs.relabel_sysfile_fifo_files`
* `fs.relabel_sysfile_files`
* `fs.relabel_sysfile_lnk_files`
* `fs.relabel_sysfile_sock_files`
* `fs.relabelfrom_sysfile`
* `fs.relabelfrom_sysfile_blk_files`
* `fs.relabelfrom_sysfile_chr_files`
* `fs.relabelfrom_sysfile_dirs`
* `fs.relabelfrom_sysfile_fifo_files`
* `fs.relabelfrom_sysfile_files`
* `fs.relabelfrom_sysfile_lnk_files`
* `fs.relabelfrom_sysfile_sock_files`
* `fs.relabelto_sysfile`
* `fs.relabelto_sysfile_blk_files`
* `fs.relabelto_sysfile_chr_files`
* `fs.relabelto_sysfile_dirs`
* `fs.relabelto_sysfile_fifo_files`
* `fs.relabelto_sysfile_files`
* `fs.relabelto_sysfile_lnk_files`
* `fs.relabelto_sysfile_sock_files`
* `fs.rename_sysfile`
* `fs.rename_sysfile_blk_files`
* `fs.rename_sysfile_chr_files`
* `fs.rename_sysfile_dirs`
* `fs.rename_sysfile_fifo_files`
* `fs.rename_sysfile_files`
* `fs.rename_sysfile_lnk_files`
* `fs.rename_sysfile_sock_files`
* `fs.search_sysfile_dirs`
* `fs.sysfile_obj_type_transition`
* `fs.write_sysfile`
* `fs.write_sysfile_blk_files`
* `fs.write_sysfile_chr_files`
* `fs.write_sysfile_dirs`
* `fs.write_sysfile_fifo_files`
* `fs.write_sysfile_files`
* `fs.write_sysfile_lnk_files`
* `fs.write_sysfile_sock_files`
* `fs.writeinherited_sysfile_blk_files`
* `fs.writeinherited_sysfile_chr_files`
* `fs.writeinherited_sysfile_dirs`
* `fs.writeinherited_sysfile_fifo_files`
* `fs.writeinherited_sysfile_files`
* `fs.writeinherited_sysfile_sock_files`

Macros providing access to `sysfile.fs.obj_typeattr`:

* `sysfile.fs.addname_all_dirs`
* `sysfile.fs.append_all_blk_files`
* `sysfile.fs.append_all_chr_files`
* `sysfile.fs.append_all_fifo_files`
* `sysfile.fs.append_all_files`
* `sysfile.fs.appendinherited_all_blk_files`
* `sysfile.fs.appendinherited_all_chr_files`
* `sysfile.fs.appendinherited_all_fifo_files`
* `sysfile.fs.appendinherited_all_files`
* `sysfile.fs.create_all`
* `sysfile.fs.create_all_blk_files`
* `sysfile.fs.create_all_chr_files`
* `sysfile.fs.create_all_dirs`
* `sysfile.fs.create_all_fifo_files`
* `sysfile.fs.create_all_files`
* `sysfile.fs.create_all_lnk_files`
* `sysfile.fs.create_all_sock_files`
* `sysfile.fs.deletename_all_dirs`
* `sysfile.fs.delete_all`
* `sysfile.fs.delete_all_blk_files`
* `sysfile.fs.delete_all_chr_files`
* `sysfile.fs.delete_all_dirs`
* `sysfile.fs.delete_all_fifo_files`
* `sysfile.fs.delete_all_files`
* `sysfile.fs.delete_all_lnk_files`
* `sysfile.fs.delete_all_sock_files`
* `sysfile.fs.execute_all_files`
* `sysfile.fs.getattr_all_files`
* `sysfile.fs.getattr_all_lnk_files`
* `sysfile.fs.list_all_dirs`
* `sysfile.fs.listinherited_all_dirs`
* `sysfile.fs.manage_all`
* `sysfile.fs.manage_all_blk_files`
* `sysfile.fs.manage_all_chr_files`
* `sysfile.fs.manage_all_dirs`
* `sysfile.fs.manage_all_fifo_files`
* `sysfile.fs.manage_all_files`
* `sysfile.fs.manage_all_lnk_files`
* `sysfile.fs.manage_all_sock_files`
* `sysfile.fs.mapexecute_all_chr_files`
* `sysfile.fs.mapexecute_all_files`
* `sysfile.fs.mounton_all`
* `sysfile.fs.mounton_all_blk_files`
* `sysfile.fs.mounton_all_chr_files`
* `sysfile.fs.mounton_all_dirs`
* `sysfile.fs.mounton_all_fifo_files`
* `sysfile.fs.mounton_all_files`
* `sysfile.fs.mounton_all_lnk_files`
* `sysfile.fs.mounton_all_sock_files`
* `sysfile.fs.obj_type`
* `sysfile.fs.read_all`
* `sysfile.fs.read_all_blk_files`
* `sysfile.fs.read_all_chr_files`
* `sysfile.fs.read_all_fifo_files`
* `sysfile.fs.read_all_files`
* `sysfile.fs.read_all_lnk_files`
* `sysfile.fs.read_all_sock_files`
* `sysfile.fs.readinherited_all_blk_files`
* `sysfile.fs.readinherited_all_chr_files`
* `sysfile.fs.readinherited_all_fifo_files`
* `sysfile.fs.readinherited_all_files`
* `sysfile.fs.readinherited_all_sock_files`
* `sysfile.fs.readwrite_all`
* `sysfile.fs.readwrite_all_blk_files`
* `sysfile.fs.readwrite_all_chr_files`
* `sysfile.fs.readwrite_all_dirs`
* `sysfile.fs.readwrite_all_fifo_files`
* `sysfile.fs.readwrite_all_files`
* `sysfile.fs.readwrite_all_lnk_files`
* `sysfile.fs.readwrite_all_sock_files`
* `sysfile.fs.readwriteinherited_all_blk_files`
* `sysfile.fs.readwriteinherited_all_chr_files`
* `sysfile.fs.readwriteinherited_all_dirs`
* `sysfile.fs.readwriteinherited_all_fifo_files`
* `sysfile.fs.readwriteinherited_all_files`
* `sysfile.fs.readwriteinherited_all_sock_files`
* `sysfile.fs.relabel_all`
* `sysfile.fs.relabel_all_blk_files`
* `sysfile.fs.relabel_all_chr_files`
* `sysfile.fs.relabel_all_dirs`
* `sysfile.fs.relabel_all_fifo_files`
* `sysfile.fs.relabel_all_files`
* `sysfile.fs.relabel_all_lnk_files`
* `sysfile.fs.relabel_all_sock_files`
* `sysfile.fs.relabelfrom_all`
* `sysfile.fs.relabelfrom_all_blk_files`
* `sysfile.fs.relabelfrom_all_chr_files`
* `sysfile.fs.relabelfrom_all_dirs`
* `sysfile.fs.relabelfrom_all_fifo_files`
* `sysfile.fs.relabelfrom_all_files`
* `sysfile.fs.relabelfrom_all_lnk_files`
* `sysfile.fs.relabelfrom_all_sock_files`
* `sysfile.fs.relabelto_all`
* `sysfile.fs.relabelto_all_blk_files`
* `sysfile.fs.relabelto_all_chr_files`
* `sysfile.fs.relabelto_all_dirs`
* `sysfile.fs.relabelto_all_fifo_files`
* `sysfile.fs.relabelto_all_files`
* `sysfile.fs.relabelto_all_lnk_files`
* `sysfile.fs.relabelto_all_sock_files`
* `sysfile.fs.rename_all`
* `sysfile.fs.rename_all_blk_files`
* `sysfile.fs.rename_all_chr_files`
* `sysfile.fs.rename_all_dirs`
* `sysfile.fs.rename_all_fifo_files`
* `sysfile.fs.rename_all_files`
* `sysfile.fs.rename_all_lnk_files`
* `sysfile.fs.rename_all_sock_files`
* `sysfile.fs.search_all_dirs`
* `sysfile.fs.write_all`
* `sysfile.fs.write_all_blk_files`
* `sysfile.fs.write_all_chr_files`
* `sysfile.fs.write_all_dirs`
* `sysfile.fs.write_all_fifo_files`
* `sysfile.fs.write_all_files`
* `sysfile.fs.write_all_lnk_files`
* `sysfile.fs.write_all_sock_files`
* `sysfile.fs.writeinherited_all_blk_files`
* `sysfile.fs.writeinherited_all_chr_files`
* `sysfile.fs.writeinherited_all_dirs`
* `sysfile.fs.writeinherited_all_fifo_files`
* `sysfile.fs.writeinherited_all_files`
* `sysfile.fs.writeinherited_all_sock_files`
* `sysfile.fs.dontaudit_manage_all_dirs`
* `sysfile.fs.dontaudit_manage_all_files`
* `sysfile.fs.dontaudit_manage_all_lnk_files`

## src/sysfile/hypervisorsysfile.cil

The `src/sysfile/hypervisorsysfile.cil` module defines Sys files and
access to them at the Hypervisor intermediate level namely
"all Sys Hypervisor files" and in addition declares a generic Sys
Hypervisor file type to be associated with `/sys/hypervisor` by
default. The Sys Hypervisor context is associated with files using
`genfscon` statements.

Available templates:

* `sysfile.hypervisor.obj_base_template` Declares a Sys Hypervisor
file
* `sysfile.hypervisor.obj_template` Declares a Sys Hypervisor file and
includes macros that provide access to the declared Sys Hypervisor
file

Macros providing access to `hypervisor.sysfile`:

* `hypervisor.addname_sysfile_dirs`
* `hypervisor.append_sysfile_blk_files`
* `hypervisor.append_sysfile_chr_files`
* `hypervisor.append_sysfile_fifo_files`
* `hypervisor.append_sysfile_files`
* `hypervisor.appendinherited_sysfile_blk_files`
* `hypervisor.appendinherited_sysfile_chr_files`
* `hypervisor.appendinherited_sysfile_fifo_files`
* `hypervisor.appendinherited_sysfile_files`
* `hypervisor.create_sysfile`
* `hypervisor.create_sysfile_blk_files`
* `hypervisor.create_sysfile_chr_files`
* `hypervisor.create_sysfile_dirs`
* `hypervisor.create_sysfile_fifo_files`
* `hypervisor.create_sysfile_files`
* `hypervisor.create_sysfile_lnk_files`
* `hypervisor.create_sysfile_sock_files`
* `hypervisor.deletename_sysfile_dirs`
* `hypervisor.delete_sysfile`
* `hypervisor.delete_sysfile_blk_files`
* `hypervisor.delete_sysfile_chr_files`
* `hypervisor.delete_sysfile_dirs`
* `hypervisor.delete_sysfile_fifo_files`
* `hypervisor.delete_sysfile_files`
* `hypervisor.delete_sysfile_lnk_files`
* `hypervisor.delete_sysfile_sock_files`
* `hypervisor.execute_sysfile_files`
* `hypervisor.getattr_sysfile_files`
* `hypervisor.getattr_sysfile_lnk_files`
* `hypervisor.list_sysfile_dirs`
* `hypervisor.listinherited_sysfile_dirs`
* `hypervisor.manage_sysfile`
* `hypervisor.manage_sysfile_blk_files`
* `hypervisor.manage_sysfile_chr_files`
* `hypervisor.manage_sysfile_dirs`
* `hypervisor.manage_sysfile_fifo_files`
* `hypervisor.manage_sysfile_files`
* `hypervisor.manage_sysfile_lnk_files`
* `hypervisor.manage_sysfile_sock_files`
* `hypervisor.mapexecute_sysfile_chr_files`
* `hypervisor.mapexecute_sysfile_files`
* `hypervisor.mounton_sysfile`
* `hypervisor.mounton_sysfile_blk_files`
* `hypervisor.mounton_sysfile_chr_files`
* `hypervisor.mounton_sysfile_dirs`
* `hypervisor.mounton_sysfile_fifo_files`
* `hypervisor.mounton_sysfile_files`
* `hypervisor.mounton_sysfile_lnk_files`
* `hypervisor.mounton_sysfile_sock_files`
* `hypervisor.read_sysfile`
* `hypervisor.read_sysfile_blk_files`
* `hypervisor.read_sysfile_chr_files`
* `hypervisor.read_sysfile_fifo_files`
* `hypervisor.read_sysfile_files`
* `hypervisor.read_sysfile_lnk_files`
* `hypervisor.read_sysfile_sock_files`
* `hypervisor.readinherited_sysfile_blk_files`
* `hypervisor.readinherited_sysfile_chr_files`
* `hypervisor.readinherited_sysfile_fifo_files`
* `hypervisor.readinherited_sysfile_files`
* `hypervisor.readinherited_sysfile_sock_files`
* `hypervisor.readwrite_sysfile`
* `hypervisor.readwrite_sysfile_blk_files`
* `hypervisor.readwrite_sysfile_chr_files`
* `hypervisor.readwrite_sysfile_dirs`
* `hypervisor.readwrite_sysfile_fifo_files`
* `hypervisor.readwrite_sysfile_files`
* `hypervisor.readwrite_sysfile_lnk_files`
* `hypervisor.readwrite_sysfile_sock_files`
* `hypervisor.readwriteinherited_sysfile_blk_files`
* `hypervisor.readwriteinherited_sysfile_chr_files`
* `hypervisor.readwriteinherited_sysfile_dirs`
* `hypervisor.readwriteinherited_sysfile_fifo_files`
* `hypervisor.readwriteinherited_sysfile_files`
* `hypervisor.readwriteinherited_sysfile_sock_files`
* `hypervisor.relabel_sysfile`
* `hypervisor.relabel_sysfile_blk_files`
* `hypervisor.relabel_sysfile_chr_files`
* `hypervisor.relabel_sysfile_dirs`
* `hypervisor.relabel_sysfile_fifo_files`
* `hypervisor.relabel_sysfile_files`
* `hypervisor.relabel_sysfile_lnk_files`
* `hypervisor.relabel_sysfile_sock_files`
* `hypervisor.relabelfrom_sysfile`
* `hypervisor.relabelfrom_sysfile_blk_files`
* `hypervisor.relabelfrom_sysfile_chr_files`
* `hypervisor.relabelfrom_sysfile_dirs`
* `hypervisor.relabelfrom_sysfile_fifo_files`
* `hypervisor.relabelfrom_sysfile_files`
* `hypervisor.relabelfrom_sysfile_lnk_files`
* `hypervisor.relabelfrom_sysfile_sock_files`
* `hypervisor.relabelto_sysfile`
* `hypervisor.relabelto_sysfile_blk_files`
* `hypervisor.relabelto_sysfile_chr_files`
* `hypervisor.relabelto_sysfile_dirs`
* `hypervisor.relabelto_sysfile_fifo_files`
* `hypervisor.relabelto_sysfile_files`
* `hypervisor.relabelto_sysfile_lnk_files`
* `hypervisor.relabelto_sysfile_sock_files`
* `hypervisor.rename_sysfile`
* `hypervisor.rename_sysfile_blk_files`
* `hypervisor.rename_sysfile_chr_files`
* `hypervisor.rename_sysfile_dirs`
* `hypervisor.rename_sysfile_fifo_files`
* `hypervisor.rename_sysfile_files`
* `hypervisor.rename_sysfile_lnk_files`
* `hypervisor.rename_sysfile_sock_files`
* `hypervisor.search_sysfile_dirs`
* `hypervisor.sysfile_obj_type_transition`
* `hypervisor.write_sysfile`
* `hypervisor.write_sysfile_blk_files`
* `hypervisor.write_sysfile_chr_files`
* `hypervisor.write_sysfile_dirs`
* `hypervisor.write_sysfile_fifo_files`
* `hypervisor.write_sysfile_files`
* `hypervisor.write_sysfile_lnk_files`
* `hypervisor.write_sysfile_sock_files`
* `hypervisor.writeinherited_sysfile_blk_files`
* `hypervisor.writeinherited_sysfile_chr_files`
* `hypervisor.writeinherited_sysfile_dirs`
* `hypervisor.writeinherited_sysfile_fifo_files`
* `hypervisor.writeinherited_sysfile_files`
* `hypervisor.writeinherited_sysfile_sock_files`

Macros providing access to `sysfile.hypervisor.obj_typeattr`:

* `sysfile.hypervisor.addname_all_dirs`
* `sysfile.hypervisor.append_all_blk_files`
* `sysfile.hypervisor.append_all_chr_files`
* `sysfile.hypervisor.append_all_fifo_files`
* `sysfile.hypervisor.append_all_files`
* `sysfile.hypervisor.appendinherited_all_blk_files`
* `sysfile.hypervisor.appendinherited_all_chr_files`
* `sysfile.hypervisor.appendinherited_all_fifo_files`
* `sysfile.hypervisor.appendinherited_all_files`
* `sysfile.hypervisor.create_all`
* `sysfile.hypervisor.create_all_blk_files`
* `sysfile.hypervisor.create_all_chr_files`
* `sysfile.hypervisor.create_all_dirs`
* `sysfile.hypervisor.create_all_fifo_files`
* `sysfile.hypervisor.create_all_files`
* `sysfile.hypervisor.create_all_lnk_files`
* `sysfile.hypervisor.create_all_sock_files`
* `sysfile.hypervisor.deletename_all_dirs`
* `sysfile.hypervisor.delete_all`
* `sysfile.hypervisor.delete_all_blk_files`
* `sysfile.hypervisor.delete_all_chr_files`
* `sysfile.hypervisor.delete_all_dirs`
* `sysfile.hypervisor.delete_all_fifo_files`
* `sysfile.hypervisor.delete_all_files`
* `sysfile.hypervisor.delete_all_lnk_files`
* `sysfile.hypervisor.delete_all_sock_files`
* `sysfile.hypervisor.execute_all_files`
* `sysfile.hypervisor.getattr_all_files`
* `sysfile.hypervisor.getattr_all_lnk_files`
* `sysfile.hypervisor.list_all_dirs`
* `sysfile.hypervisor.listinherited_all_dirs`
* `sysfile.hypervisor.manage_all`
* `sysfile.hypervisor.manage_all_blk_files`
* `sysfile.hypervisor.manage_all_chr_files`
* `sysfile.hypervisor.manage_all_dirs`
* `sysfile.hypervisor.manage_all_fifo_files`
* `sysfile.hypervisor.manage_all_files`
* `sysfile.hypervisor.manage_all_lnk_files`
* `sysfile.hypervisor.manage_all_sock_files`
* `sysfile.hypervisor.mapexecute_all_chr_files`
* `sysfile.hypervisor.mapexecute_all_files`
* `sysfile.hypervisor.mounton_all`
* `sysfile.hypervisor.mounton_all_blk_files`
* `sysfile.hypervisor.mounton_all_chr_files`
* `sysfile.hypervisor.mounton_all_dirs`
* `sysfile.hypervisor.mounton_all_fifo_files`
* `sysfile.hypervisor.mounton_all_files`
* `sysfile.hypervisor.mounton_all_lnk_files`
* `sysfile.hypervisor.mounton_all_sock_files`
* `sysfile.hypervisor.obj_type`
* `sysfile.hypervisor.read_all`
* `sysfile.hypervisor.read_all_blk_files`
* `sysfile.hypervisor.read_all_chr_files`
* `sysfile.hypervisor.read_all_fifo_files`
* `sysfile.hypervisor.read_all_files`
* `sysfile.hypervisor.read_all_lnk_files`
* `sysfile.hypervisor.read_all_sock_files`
* `sysfile.hypervisor.readinherited_all_blk_files`
* `sysfile.hypervisor.readinherited_all_chr_files`
* `sysfile.hypervisor.readinherited_all_fifo_files`
* `sysfile.hypervisor.readinherited_all_files`
* `sysfile.hypervisor.readinherited_all_sock_files`
* `sysfile.hypervisor.readwrite_all`
* `sysfile.hypervisor.readwrite_all_blk_files`
* `sysfile.hypervisor.readwrite_all_chr_files`
* `sysfile.hypervisor.readwrite_all_dirs`
* `sysfile.hypervisor.readwrite_all_fifo_files`
* `sysfile.hypervisor.readwrite_all_files`
* `sysfile.hypervisor.readwrite_all_lnk_files`
* `sysfile.hypervisor.readwrite_all_sock_files`
* `sysfile.hypervisor.readwriteinherited_all_blk_files`
* `sysfile.hypervisor.readwriteinherited_all_chr_files`
* `sysfile.hypervisor.readwriteinherited_all_dirs`
* `sysfile.hypervisor.readwriteinherited_all_fifo_files`
* `sysfile.hypervisor.readwriteinherited_all_files`
* `sysfile.hypervisor.readwriteinherited_all_sock_files`
* `sysfile.hypervisor.relabel_all`
* `sysfile.hypervisor.relabel_all_blk_files`
* `sysfile.hypervisor.relabel_all_chr_files`
* `sysfile.hypervisor.relabel_all_dirs`
* `sysfile.hypervisor.relabel_all_fifo_files`
* `sysfile.hypervisor.relabel_all_files`
* `sysfile.hypervisor.relabel_all_lnk_files`
* `sysfile.hypervisor.relabel_all_sock_files`
* `sysfile.hypervisor.relabelfrom_all`
* `sysfile.hypervisor.relabelfrom_all_blk_files`
* `sysfile.hypervisor.relabelfrom_all_chr_files`
* `sysfile.hypervisor.relabelfrom_all_dirs`
* `sysfile.hypervisor.relabelfrom_all_fifo_files`
* `sysfile.hypervisor.relabelfrom_all_files`
* `sysfile.hypervisor.relabelfrom_all_lnk_files`
* `sysfile.hypervisor.relabelfrom_all_sock_files`
* `sysfile.hypervisor.relabelto_all`
* `sysfile.hypervisor.relabelto_all_blk_files`
* `sysfile.hypervisor.relabelto_all_chr_files`
* `sysfile.hypervisor.relabelto_all_dirs`
* `sysfile.hypervisor.relabelto_all_fifo_files`
* `sysfile.hypervisor.relabelto_all_files`
* `sysfile.hypervisor.relabelto_all_lnk_files`
* `sysfile.hypervisor.relabelto_all_sock_files`
* `sysfile.hypervisor.rename_all`
* `sysfile.hypervisor.rename_all_blk_files`
* `sysfile.hypervisor.rename_all_chr_files`
* `sysfile.hypervisor.rename_all_dirs`
* `sysfile.hypervisor.rename_all_fifo_files`
* `sysfile.hypervisor.rename_all_files`
* `sysfile.hypervisor.rename_all_lnk_files`
* `sysfile.hypervisor.rename_all_sock_files`
* `sysfile.hypervisor.search_all_dirs`
* `sysfile.hypervisor.write_all`
* `sysfile.hypervisor.write_all_blk_files`
* `sysfile.hypervisor.write_all_chr_files`
* `sysfile.hypervisor.write_all_dirs`
* `sysfile.hypervisor.write_all_fifo_files`
* `sysfile.hypervisor.write_all_files`
* `sysfile.hypervisor.write_all_lnk_files`
* `sysfile.hypervisor.write_all_sock_files`
* `sysfile.hypervisor.writeinherited_all_blk_files`
* `sysfile.hypervisor.writeinherited_all_chr_files`
* `sysfile.hypervisor.writeinherited_all_dirs`
* `sysfile.hypervisor.writeinherited_all_fifo_files`
* `sysfile.hypervisor.writeinherited_all_files`
* `sysfile.hypervisor.writeinherited_all_sock_files`
* `sysfile.hypervisor.dontaudit_manage_all_dirs`
* `sysfile.hypervisor.dontaudit_manage_all_files`
* `sysfile.hypervisor.dontaudit_manage_all_lnk_files`

## src/sysfile/kernelsysfile.cil

The `src/sysfile/kernelsysfile.cil` module defines Sys files and
access to them at the Kernel intermediate level namely
"all Sys Kernel files" and in addition declares a generic Sys Kernel
file type to be associated with `/sys/kernel` by default. The Sys
Kernel context is associated with files using `genfscon` statements.

Available templates:

* `sysfile.kernel.obj_base_template` Declares a Sys Kernel file
* `sysfile.kernel.obj_template` Declares a Sys Kernel file and
includes macros that provide access to the declared Sys Kernel file

Macros providing access to `kernel.sysfile`:

* `kernel.addname_sysfile_dirs`
* `kernel.append_sysfile_blk_files`
* `kernel.append_sysfile_chr_files`
* `kernel.append_sysfile_fifo_files`
* `kernel.append_sysfile_files`
* `kernel.appendinherited_sysfile_blk_files`
* `kernel.appendinherited_sysfile_chr_files`
* `kernel.appendinherited_sysfile_fifo_files`
* `kernel.appendinherited_sysfile_files`
* `kernel.create_sysfile`
* `kernel.create_sysfile_blk_files`
* `kernel.create_sysfile_chr_files`
* `kernel.create_sysfile_dirs`
* `kernel.create_sysfile_fifo_files`
* `kernel.create_sysfile_files`
* `kernel.create_sysfile_lnk_files`
* `kernel.create_sysfile_sock_files`
* `kernel.deletename_sysfile_dirs`
* `kernel.delete_sysfile`
* `kernel.delete_sysfile_blk_files`
* `kernel.delete_sysfile_chr_files`
* `kernel.delete_sysfile_dirs`
* `kernel.delete_sysfile_fifo_files`
* `kernel.delete_sysfile_files`
* `kernel.delete_sysfile_lnk_files`
* `kernel.delete_sysfile_sock_files`
* `kernel.execute_sysfile_files`
* `kernel.getattr_sysfile_files`
* `kernel.getattr_sysfile_lnk_files`
* `kernel.list_sysfile_dirs`
* `kernel.listinherited_sysfile_dirs`
* `kernel.manage_sysfile`
* `kernel.manage_sysfile_blk_files`
* `kernel.manage_sysfile_chr_files`
* `kernel.manage_sysfile_dirs`
* `kernel.manage_sysfile_fifo_files`
* `kernel.manage_sysfile_files`
* `kernel.manage_sysfile_lnk_files`
* `kernel.manage_sysfile_sock_files`
* `kernel.mapexecute_sysfile_chr_files`
* `kernel.mapexecute_sysfile_files`
* `kernel.mounton_sysfile`
* `kernel.mounton_sysfile_blk_files`
* `kernel.mounton_sysfile_chr_files`
* `kernel.mounton_sysfile_dirs`
* `kernel.mounton_sysfile_fifo_files`
* `kernel.mounton_sysfile_files`
* `kernel.mounton_sysfile_lnk_files`
* `kernel.mounton_sysfile_sock_files`
* `kernel.read_sysfile`
* `kernel.read_sysfile_blk_files`
* `kernel.read_sysfile_chr_files`
* `kernel.read_sysfile_fifo_files`
* `kernel.read_sysfile_files`
* `kernel.read_sysfile_lnk_files`
* `kernel.read_sysfile_sock_files`
* `kernel.readinherited_sysfile_blk_files`
* `kernel.readinherited_sysfile_chr_files`
* `kernel.readinherited_sysfile_fifo_files`
* `kernel.readinherited_sysfile_files`
* `kernel.readinherited_sysfile_sock_files`
* `kernel.readwrite_sysfile`
* `kernel.readwrite_sysfile_blk_files`
* `kernel.readwrite_sysfile_chr_files`
* `kernel.readwrite_sysfile_dirs`
* `kernel.readwrite_sysfile_fifo_files`
* `kernel.readwrite_sysfile_files`
* `kernel.readwrite_sysfile_lnk_files`
* `kernel.readwrite_sysfile_sock_files`
* `kernel.readwriteinherited_sysfile_blk_files`
* `kernel.readwriteinherited_sysfile_chr_files`
* `kernel.readwriteinherited_sysfile_dirs`
* `kernel.readwriteinherited_sysfile_fifo_files`
* `kernel.readwriteinherited_sysfile_files`
* `kernel.readwriteinherited_sysfile_sock_files`
* `kernel.relabel_sysfile`
* `kernel.relabel_sysfile_blk_files`
* `kernel.relabel_sysfile_chr_files`
* `kernel.relabel_sysfile_dirs`
* `kernel.relabel_sysfile_fifo_files`
* `kernel.relabel_sysfile_files`
* `kernel.relabel_sysfile_lnk_files`
* `kernel.relabel_sysfile_sock_files`
* `kernel.relabelfrom_sysfile`
* `kernel.relabelfrom_sysfile_blk_files`
* `kernel.relabelfrom_sysfile_chr_files`
* `kernel.relabelfrom_sysfile_dirs`
* `kernel.relabelfrom_sysfile_fifo_files`
* `kernel.relabelfrom_sysfile_files`
* `kernel.relabelfrom_sysfile_lnk_files`
* `kernel.relabelfrom_sysfile_sock_files`
* `kernel.relabelto_sysfile`
* `kernel.relabelto_sysfile_blk_files`
* `kernel.relabelto_sysfile_chr_files`
* `kernel.relabelto_sysfile_dirs`
* `kernel.relabelto_sysfile_fifo_files`
* `kernel.relabelto_sysfile_files`
* `kernel.relabelto_sysfile_lnk_files`
* `kernel.relabelto_sysfile_sock_files`
* `kernel.rename_sysfile`
* `kernel.rename_sysfile_blk_files`
* `kernel.rename_sysfile_chr_files`
* `kernel.rename_sysfile_dirs`
* `kernel.rename_sysfile_fifo_files`
* `kernel.rename_sysfile_files`
* `kernel.rename_sysfile_lnk_files`
* `kernel.rename_sysfile_sock_files`
* `kernel.search_sysfile_dirs`
* `kernel.sysfile_obj_type_transition`
* `kernel.write_sysfile`
* `kernel.write_sysfile_blk_files`
* `kernel.write_sysfile_chr_files`
* `kernel.write_sysfile_dirs`
* `kernel.write_sysfile_fifo_files`
* `kernel.write_sysfile_files`
* `kernel.write_sysfile_lnk_files`
* `kernel.write_sysfile_sock_files`
* `kernel.writeinherited_sysfile_blk_files`
* `kernel.writeinherited_sysfile_chr_files`
* `kernel.writeinherited_sysfile_dirs`
* `kernel.writeinherited_sysfile_fifo_files`
* `kernel.writeinherited_sysfile_files`
* `kernel.writeinherited_sysfile_sock_files`

Macros providing access to `sysfile.kernel.obj_typeattr`:

* `sysfile.kernel.addname_all_dirs`
* `sysfile.kernel.append_all_blk_files`
* `sysfile.kernel.append_all_chr_files`
* `sysfile.kernel.append_all_fifo_files`
* `sysfile.kernel.append_all_files`
* `sysfile.kernel.appendinherited_all_blk_files`
* `sysfile.kernel.appendinherited_all_chr_files`
* `sysfile.kernel.appendinherited_all_fifo_files`
* `sysfile.kernel.appendinherited_all_files`
* `sysfile.kernel.create_all`
* `sysfile.kernel.create_all_blk_files`
* `sysfile.kernel.create_all_chr_files`
* `sysfile.kernel.create_all_dirs`
* `sysfile.kernel.create_all_fifo_files`
* `sysfile.kernel.create_all_files`
* `sysfile.kernel.create_all_lnk_files`
* `sysfile.kernel.create_all_sock_files`
* `sysfile.kernel.deletename_all_dirs`
* `sysfile.kernel.delete_all`
* `sysfile.kernel.delete_all_blk_files`
* `sysfile.kernel.delete_all_chr_files`
* `sysfile.kernel.delete_all_dirs`
* `sysfile.kernel.delete_all_fifo_files`
* `sysfile.kernel.delete_all_files`
* `sysfile.kernel.delete_all_lnk_files`
* `sysfile.kernel.delete_all_sock_files`
* `sysfile.kernel.execute_all_files`
* `sysfile.kernel.getattr_all_files`
* `sysfile.kernel.getattr_all_lnk_files`
* `sysfile.kernel.list_all_dirs`
* `sysfile.kernel.listinherited_all_dirs`
* `sysfile.kernel.manage_all`
* `sysfile.kernel.manage_all_blk_files`
* `sysfile.kernel.manage_all_chr_files`
* `sysfile.kernel.manage_all_dirs`
* `sysfile.kernel.manage_all_fifo_files`
* `sysfile.kernel.manage_all_files`
* `sysfile.kernel.manage_all_lnk_files`
* `sysfile.kernel.manage_all_sock_files`
* `sysfile.kernel.mapexecute_all_chr_files`
* `sysfile.kernel.mapexecute_all_files`
* `sysfile.kernel.mounton_all`
* `sysfile.kernel.mounton_all_blk_files`
* `sysfile.kernel.mounton_all_chr_files`
* `sysfile.kernel.mounton_all_dirs`
* `sysfile.kernel.mounton_all_fifo_files`
* `sysfile.kernel.mounton_all_files`
* `sysfile.kernel.mounton_all_lnk_files`
* `sysfile.kernel.mounton_all_sock_files`
* `sysfile.kernel.obj_type`
* `sysfile.kernel.read_all`
* `sysfile.kernel.read_all_blk_files`
* `sysfile.kernel.read_all_chr_files`
* `sysfile.kernel.read_all_fifo_files`
* `sysfile.kernel.read_all_files`
* `sysfile.kernel.read_all_lnk_files`
* `sysfile.kernel.read_all_sock_files`
* `sysfile.kernel.readinherited_all_blk_files`
* `sysfile.kernel.readinherited_all_chr_files`
* `sysfile.kernel.readinherited_all_fifo_files`
* `sysfile.kernel.readinherited_all_files`
* `sysfile.kernel.readinherited_all_sock_files`
* `sysfile.kernel.readwrite_all`
* `sysfile.kernel.readwrite_all_blk_files`
* `sysfile.kernel.readwrite_all_chr_files`
* `sysfile.kernel.readwrite_all_dirs`
* `sysfile.kernel.readwrite_all_fifo_files`
* `sysfile.kernel.readwrite_all_files`
* `sysfile.kernel.readwrite_all_lnk_files`
* `sysfile.kernel.readwrite_all_sock_files`
* `sysfile.kernel.readwriteinherited_all_blk_files`
* `sysfile.kernel.readwriteinherited_all_chr_files`
* `sysfile.kernel.readwriteinherited_all_dirs`
* `sysfile.kernel.readwriteinherited_all_fifo_files`
* `sysfile.kernel.readwriteinherited_all_files`
* `sysfile.kernel.readwriteinherited_all_sock_files`
* `sysfile.kernel.relabel_all`
* `sysfile.kernel.relabel_all_blk_files`
* `sysfile.kernel.relabel_all_chr_files`
* `sysfile.kernel.relabel_all_dirs`
* `sysfile.kernel.relabel_all_fifo_files`
* `sysfile.kernel.relabel_all_files`
* `sysfile.kernel.relabel_all_lnk_files`
* `sysfile.kernel.relabel_all_sock_files`
* `sysfile.kernel.relabelfrom_all`
* `sysfile.kernel.relabelfrom_all_blk_files`
* `sysfile.kernel.relabelfrom_all_chr_files`
* `sysfile.kernel.relabelfrom_all_dirs`
* `sysfile.kernel.relabelfrom_all_fifo_files`
* `sysfile.kernel.relabelfrom_all_files`
* `sysfile.kernel.relabelfrom_all_lnk_files`
* `sysfile.kernel.relabelfrom_all_sock_files`
* `sysfile.kernel.relabelto_all`
* `sysfile.kernel.relabelto_all_blk_files`
* `sysfile.kernel.relabelto_all_chr_files`
* `sysfile.kernel.relabelto_all_dirs`
* `sysfile.kernel.relabelto_all_fifo_files`
* `sysfile.kernel.relabelto_all_files`
* `sysfile.kernel.relabelto_all_lnk_files`
* `sysfile.kernel.relabelto_all_sock_files`
* `sysfile.kernel.rename_all`
* `sysfile.kernel.rename_all_blk_files`
* `sysfile.kernel.rename_all_chr_files`
* `sysfile.kernel.rename_all_dirs`
* `sysfile.kernel.rename_all_fifo_files`
* `sysfile.kernel.rename_all_files`
* `sysfile.kernel.rename_all_lnk_files`
* `sysfile.kernel.rename_all_sock_files`
* `sysfile.kernel.search_all_dirs`
* `sysfile.kernel.write_all`
* `sysfile.kernel.write_all_blk_files`
* `sysfile.kernel.write_all_chr_files`
* `sysfile.kernel.write_all_dirs`
* `sysfile.kernel.write_all_fifo_files`
* `sysfile.kernel.write_all_files`
* `sysfile.kernel.write_all_lnk_files`
* `sysfile.kernel.write_all_sock_files`
* `sysfile.kernel.writeinherited_all_blk_files`
* `sysfile.kernel.writeinherited_all_chr_files`
* `sysfile.kernel.writeinherited_all_dirs`
* `sysfile.kernel.writeinherited_all_fifo_files`
* `sysfile.kernel.writeinherited_all_files`
* `sysfile.kernel.writeinherited_all_sock_files`
* `sysfile.kernel.dontaudit_manage_all_dirs`
* `sysfile.kernel.dontaudit_manage_all_files`
* `sysfile.kernel.dontaudit_manage_all_lnk_files`

## src/sysfile/modulesysfile.cil

The `src/sysfile/modulesysfile.cil` module defines Sys files and
access to them at the Module intermediate level namely
"all Sys Module files" and in addition declares a generic Sys Module
file type to be associated with `/sys/module` by default. The Sys
Module context is associated with files using `genfscon` statements.

Available templates:

* `sysfile.module.obj_base_template` Declares a Sys Module file
* `sysfile.module.obj_template` Declares a Sys Module file and
includes macros that provide access to the declared Sys Module file

Macros providing access to `module.sysfile`:

* `module.addname_sysfile_dirs`
* `module.append_sysfile_blk_files`
* `module.append_sysfile_chr_files`
* `module.append_sysfile_fifo_files`
* `module.append_sysfile_files`
* `module.appendinherited_sysfile_blk_files`
* `module.appendinherited_sysfile_chr_files`
* `module.appendinherited_sysfile_fifo_files`
* `module.appendinherited_sysfile_files`
* `module.create_sysfile`
* `module.create_sysfile_blk_files`
* `module.create_sysfile_chr_files`
* `module.create_sysfile_dirs`
* `module.create_sysfile_fifo_files`
* `module.create_sysfile_files`
* `module.create_sysfile_lnk_files`
* `module.create_sysfile_sock_files`
* `module.deletename_sysfile_dirs`
* `module.delete_sysfile`
* `module.delete_sysfile_blk_files`
* `module.delete_sysfile_chr_files`
* `module.delete_sysfile_dirs`
* `module.delete_sysfile_fifo_files`
* `module.delete_sysfile_files`
* `module.delete_sysfile_lnk_files`
* `module.delete_sysfile_sock_files`
* `module.execute_sysfile_files`
* `module.getattr_sysfile_files`
* `module.getattr_sysfile_lnk_files`
* `module.list_sysfile_dirs`
* `module.listinherited_sysfile_dirs`
* `module.manage_sysfile`
* `module.manage_sysfile_blk_files`
* `module.manage_sysfile_chr_files`
* `module.manage_sysfile_dirs`
* `module.manage_sysfile_fifo_files`
* `module.manage_sysfile_files`
* `module.manage_sysfile_lnk_files`
* `module.manage_sysfile_sock_files`
* `module.mapexecute_sysfile_chr_files`
* `module.mapexecute_sysfile_files`
* `module.mounton_sysfile`
* `module.mounton_sysfile_blk_files`
* `module.mounton_sysfile_chr_files`
* `module.mounton_sysfile_dirs`
* `module.mounton_sysfile_fifo_files`
* `module.mounton_sysfile_files`
* `module.mounton_sysfile_lnk_files`
* `module.mounton_sysfile_sock_files`
* `module.read_sysfile`
* `module.read_sysfile_blk_files`
* `module.read_sysfile_chr_files`
* `module.read_sysfile_fifo_files`
* `module.read_sysfile_files`
* `module.read_sysfile_lnk_files`
* `module.read_sysfile_sock_files`
* `module.readinherited_sysfile_blk_files`
* `module.readinherited_sysfile_chr_files`
* `module.readinherited_sysfile_fifo_files`
* `module.readinherited_sysfile_files`
* `module.readinherited_sysfile_sock_files`
* `module.readwrite_sysfile`
* `module.readwrite_sysfile_blk_files`
* `module.readwrite_sysfile_chr_files`
* `module.readwrite_sysfile_dirs`
* `module.readwrite_sysfile_fifo_files`
* `module.readwrite_sysfile_files`
* `module.readwrite_sysfile_lnk_files`
* `module.readwrite_sysfile_sock_files`
* `module.readwriteinherited_sysfile_blk_files`
* `module.readwriteinherited_sysfile_chr_files`
* `module.readwriteinherited_sysfile_dirs`
* `module.readwriteinherited_sysfile_fifo_files`
* `module.readwriteinherited_sysfile_files`
* `module.readwriteinherited_sysfile_sock_files`
* `module.relabel_sysfile`
* `module.relabel_sysfile_blk_files`
* `module.relabel_sysfile_chr_files`
* `module.relabel_sysfile_dirs`
* `module.relabel_sysfile_fifo_files`
* `module.relabel_sysfile_files`
* `module.relabel_sysfile_lnk_files`
* `module.relabel_sysfile_sock_files`
* `module.relabelfrom_sysfile`
* `module.relabelfrom_sysfile_blk_files`
* `module.relabelfrom_sysfile_chr_files`
* `module.relabelfrom_sysfile_dirs`
* `module.relabelfrom_sysfile_fifo_files`
* `module.relabelfrom_sysfile_files`
* `module.relabelfrom_sysfile_lnk_files`
* `module.relabelfrom_sysfile_sock_files`
* `module.relabelto_sysfile`
* `module.relabelto_sysfile_blk_files`
* `module.relabelto_sysfile_chr_files`
* `module.relabelto_sysfile_dirs`
* `module.relabelto_sysfile_fifo_files`
* `module.relabelto_sysfile_files`
* `module.relabelto_sysfile_lnk_files`
* `module.relabelto_sysfile_sock_files`
* `module.rename_sysfile`
* `module.rename_sysfile_blk_files`
* `module.rename_sysfile_chr_files`
* `module.rename_sysfile_dirs`
* `module.rename_sysfile_fifo_files`
* `module.rename_sysfile_files`
* `module.rename_sysfile_lnk_files`
* `module.rename_sysfile_sock_files`
* `module.search_sysfile_dirs`
* `module.sysfile_obj_type_transition`
* `module.write_sysfile`
* `module.write_sysfile_blk_files`
* `module.write_sysfile_chr_files`
* `module.write_sysfile_dirs`
* `module.write_sysfile_fifo_files`
* `module.write_sysfile_files`
* `module.write_sysfile_lnk_files`
* `module.write_sysfile_sock_files`
* `module.writeinherited_sysfile_blk_files`
* `module.writeinherited_sysfile_chr_files`
* `module.writeinherited_sysfile_dirs`
* `module.writeinherited_sysfile_fifo_files`
* `module.writeinherited_sysfile_files`
* `module.writeinherited_sysfile_sock_files`

Macros providing access to `sysfile.module.obj_typeattr`:

* `sysfile.module.addname_all_dirs`
* `sysfile.module.append_all_blk_files`
* `sysfile.module.append_all_chr_files`
* `sysfile.module.append_all_fifo_files`
* `sysfile.module.append_all_files`
* `sysfile.module.appendinherited_all_blk_files`
* `sysfile.module.appendinherited_all_chr_files`
* `sysfile.module.appendinherited_all_fifo_files`
* `sysfile.module.appendinherited_all_files`
* `sysfile.module.create_all`
* `sysfile.module.create_all_blk_files`
* `sysfile.module.create_all_chr_files`
* `sysfile.module.create_all_dirs`
* `sysfile.module.create_all_fifo_files`
* `sysfile.module.create_all_files`
* `sysfile.module.create_all_lnk_files`
* `sysfile.module.create_all_sock_files`
* `sysfile.module.deletename_all_dirs`
* `sysfile.module.delete_all`
* `sysfile.module.delete_all_blk_files`
* `sysfile.module.delete_all_chr_files`
* `sysfile.module.delete_all_dirs`
* `sysfile.module.delete_all_fifo_files`
* `sysfile.module.delete_all_files`
* `sysfile.module.delete_all_lnk_files`
* `sysfile.module.delete_all_sock_files`
* `sysfile.module.execute_all_files`
* `sysfile.module.getattr_all_files`
* `sysfile.module.getattr_all_lnk_files`
* `sysfile.module.list_all_dirs`
* `sysfile.module.listinherited_all_dirs`
* `sysfile.module.manage_all`
* `sysfile.module.manage_all_blk_files`
* `sysfile.module.manage_all_chr_files`
* `sysfile.module.manage_all_dirs`
* `sysfile.module.manage_all_fifo_files`
* `sysfile.module.manage_all_files`
* `sysfile.module.manage_all_lnk_files`
* `sysfile.module.manage_all_sock_files`
* `sysfile.module.mapexecute_all_chr_files`
* `sysfile.module.mapexecute_all_files`
* `sysfile.module.mounton_all`
* `sysfile.module.mounton_all_blk_files`
* `sysfile.module.mounton_all_chr_files`
* `sysfile.module.mounton_all_dirs`
* `sysfile.module.mounton_all_fifo_files`
* `sysfile.module.mounton_all_files`
* `sysfile.module.mounton_all_lnk_files`
* `sysfile.module.mounton_all_sock_files`
* `sysfile.module.obj_type`
* `sysfile.module.read_all`
* `sysfile.module.read_all_blk_files`
* `sysfile.module.read_all_chr_files`
* `sysfile.module.read_all_fifo_files`
* `sysfile.module.read_all_files`
* `sysfile.module.read_all_lnk_files`
* `sysfile.module.read_all_sock_files`
* `sysfile.module.readinherited_all_blk_files`
* `sysfile.module.readinherited_all_chr_files`
* `sysfile.module.readinherited_all_fifo_files`
* `sysfile.module.readinherited_all_files`
* `sysfile.module.readinherited_all_sock_files`
* `sysfile.module.readwrite_all`
* `sysfile.module.readwrite_all_blk_files`
* `sysfile.module.readwrite_all_chr_files`
* `sysfile.module.readwrite_all_dirs`
* `sysfile.module.readwrite_all_fifo_files`
* `sysfile.module.readwrite_all_files`
* `sysfile.module.readwrite_all_lnk_files`
* `sysfile.module.readwrite_all_sock_files`
* `sysfile.module.readwriteinherited_all_blk_files`
* `sysfile.module.readwriteinherited_all_chr_files`
* `sysfile.module.readwriteinherited_all_dirs`
* `sysfile.module.readwriteinherited_all_fifo_files`
* `sysfile.module.readwriteinherited_all_files`
* `sysfile.module.readwriteinherited_all_sock_files`
* `sysfile.module.relabel_all`
* `sysfile.module.relabel_all_blk_files`
* `sysfile.module.relabel_all_chr_files`
* `sysfile.module.relabel_all_dirs`
* `sysfile.module.relabel_all_fifo_files`
* `sysfile.module.relabel_all_files`
* `sysfile.module.relabel_all_lnk_files`
* `sysfile.module.relabel_all_sock_files`
* `sysfile.module.relabelfrom_all`
* `sysfile.module.relabelfrom_all_blk_files`
* `sysfile.module.relabelfrom_all_chr_files`
* `sysfile.module.relabelfrom_all_dirs`
* `sysfile.module.relabelfrom_all_fifo_files`
* `sysfile.module.relabelfrom_all_files`
* `sysfile.module.relabelfrom_all_lnk_files`
* `sysfile.module.relabelfrom_all_sock_files`
* `sysfile.module.relabelto_all`
* `sysfile.module.relabelto_all_blk_files`
* `sysfile.module.relabelto_all_chr_files`
* `sysfile.module.relabelto_all_dirs`
* `sysfile.module.relabelto_all_fifo_files`
* `sysfile.module.relabelto_all_files`
* `sysfile.module.relabelto_all_lnk_files`
* `sysfile.module.relabelto_all_sock_files`
* `sysfile.module.rename_all`
* `sysfile.module.rename_all_blk_files`
* `sysfile.module.rename_all_chr_files`
* `sysfile.module.rename_all_dirs`
* `sysfile.module.rename_all_fifo_files`
* `sysfile.module.rename_all_files`
* `sysfile.module.rename_all_lnk_files`
* `sysfile.module.rename_all_sock_files`
* `sysfile.module.search_all_dirs`
* `sysfile.module.write_all`
* `sysfile.module.write_all_blk_files`
* `sysfile.module.write_all_chr_files`
* `sysfile.module.write_all_dirs`
* `sysfile.module.write_all_fifo_files`
* `sysfile.module.write_all_files`
* `sysfile.module.write_all_lnk_files`
* `sysfile.module.write_all_sock_files`
* `sysfile.module.writeinherited_all_blk_files`
* `sysfile.module.writeinherited_all_chr_files`
* `sysfile.module.writeinherited_all_dirs`
* `sysfile.module.writeinherited_all_fifo_files`
* `sysfile.module.writeinherited_all_files`
* `sysfile.module.writeinherited_all_sock_files`
* `sysfile.module.dontaudit_manage_all_dirs`
* `sysfile.module.dontaudit_manage_all_files`
* `sysfile.module.dontaudit_manage_all_lnk_files`

## src/sysfile/powersysfile.cil

The `src/sysfile/powersysfile.cil` module defines Sys files and
access to them at the Power intermediate level namely
"all Sys Power files" and in addition declares a generic Sys Power
file type to be associated with `/sys/power` by default. The Sys Power
context is associated with files using `genfscon` statements.

Available templates:

* `sysfile.power.obj_base_template` Declares a Sys Power file
* `sysfile.power.obj_template` Declares a Sys Power file and includes
macros that provide access to the declared Sys Power file

Macros providing access to `power.sysfile`:

* `power.addname_sysfile_dirs`
* `power.append_sysfile_blk_files`
* `power.append_sysfile_chr_files`
* `power.append_sysfile_fifo_files`
* `power.append_sysfile_files`
* `power.appendinherited_sysfile_blk_files`
* `power.appendinherited_sysfile_chr_files`
* `power.appendinherited_sysfile_fifo_files`
* `power.appendinherited_sysfile_files`
* `power.create_sysfile`
* `power.create_sysfile_blk_files`
* `power.create_sysfile_chr_files`
* `power.create_sysfile_dirs`
* `power.create_sysfile_fifo_files`
* `power.create_sysfile_files`
* `power.create_sysfile_lnk_files`
* `power.create_sysfile_sock_files`
* `power.deletename_sysfile_dirs`
* `power.delete_sysfile`
* `power.delete_sysfile_blk_files`
* `power.delete_sysfile_chr_files`
* `power.delete_sysfile_dirs`
* `power.delete_sysfile_fifo_files`
* `power.delete_sysfile_files`
* `power.delete_sysfile_lnk_files`
* `power.delete_sysfile_sock_files`
* `power.execute_sysfile_files`
* `power.getattr_sysfile_files`
* `power.getattr_sysfile_lnk_files`
* `power.list_sysfile_dirs`
* `power.listinherited_sysfile_dirs`
* `power.manage_sysfile`
* `power.manage_sysfile_blk_files`
* `power.manage_sysfile_chr_files`
* `power.manage_sysfile_dirs`
* `power.manage_sysfile_fifo_files`
* `power.manage_sysfile_files`
* `power.manage_sysfile_lnk_files`
* `power.manage_sysfile_sock_files`
* `power.mapexecute_sysfile_chr_files`
* `power.mapexecute_sysfile_files`
* `power.mounton_sysfile`
* `power.mounton_sysfile_blk_files`
* `power.mounton_sysfile_chr_files`
* `power.mounton_sysfile_dirs`
* `power.mounton_sysfile_fifo_files`
* `power.mounton_sysfile_files`
* `power.mounton_sysfile_lnk_files`
* `power.mounton_sysfile_sock_files`
* `power.read_sysfile`
* `power.read_sysfile_blk_files`
* `power.read_sysfile_chr_files`
* `power.read_sysfile_fifo_files`
* `power.read_sysfile_files`
* `power.read_sysfile_lnk_files`
* `power.read_sysfile_sock_files`
* `power.readinherited_sysfile_blk_files`
* `power.readinherited_sysfile_chr_files`
* `power.readinherited_sysfile_fifo_files`
* `power.readinherited_sysfile_files`
* `power.readinherited_sysfile_sock_files`
* `power.readwrite_sysfile`
* `power.readwrite_sysfile_blk_files`
* `power.readwrite_sysfile_chr_files`
* `power.readwrite_sysfile_dirs`
* `power.readwrite_sysfile_fifo_files`
* `power.readwrite_sysfile_files`
* `power.readwrite_sysfile_lnk_files`
* `power.readwrite_sysfile_sock_files`
* `power.readwriteinherited_sysfile_blk_files`
* `power.readwriteinherited_sysfile_chr_files`
* `power.readwriteinherited_sysfile_dirs`
* `power.readwriteinherited_sysfile_fifo_files`
* `power.readwriteinherited_sysfile_files`
* `power.readwriteinherited_sysfile_sock_files`
* `power.relabel_sysfile`
* `power.relabel_sysfile_blk_files`
* `power.relabel_sysfile_chr_files`
* `power.relabel_sysfile_dirs`
* `power.relabel_sysfile_fifo_files`
* `power.relabel_sysfile_files`
* `power.relabel_sysfile_lnk_files`
* `power.relabel_sysfile_sock_files`
* `power.relabelfrom_sysfile`
* `power.relabelfrom_sysfile_blk_files`
* `power.relabelfrom_sysfile_chr_files`
* `power.relabelfrom_sysfile_dirs`
* `power.relabelfrom_sysfile_fifo_files`
* `power.relabelfrom_sysfile_files`
* `power.relabelfrom_sysfile_lnk_files`
* `power.relabelfrom_sysfile_sock_files`
* `power.relabelto_sysfile`
* `power.relabelto_sysfile_blk_files`
* `power.relabelto_sysfile_chr_files`
* `power.relabelto_sysfile_dirs`
* `power.relabelto_sysfile_fifo_files`
* `power.relabelto_sysfile_files`
* `power.relabelto_sysfile_lnk_files`
* `power.relabelto_sysfile_sock_files`
* `power.rename_sysfile`
* `power.rename_sysfile_blk_files`
* `power.rename_sysfile_chr_files`
* `power.rename_sysfile_dirs`
* `power.rename_sysfile_fifo_files`
* `power.rename_sysfile_files`
* `power.rename_sysfile_lnk_files`
* `power.rename_sysfile_sock_files`
* `power.search_sysfile_dirs`
* `power.sysfile_obj_type_transition`
* `power.write_sysfile`
* `power.write_sysfile_blk_files`
* `power.write_sysfile_chr_files`
* `power.write_sysfile_dirs`
* `power.write_sysfile_fifo_files`
* `power.write_sysfile_files`
* `power.write_sysfile_lnk_files`
* `power.write_sysfile_sock_files`
* `power.writeinherited_sysfile_blk_files`
* `power.writeinherited_sysfile_chr_files`
* `power.writeinherited_sysfile_dirs`
* `power.writeinherited_sysfile_fifo_files`
* `power.writeinherited_sysfile_files`
* `power.writeinherited_sysfile_sock_files`

Macros providing access to `sysfile.power.obj_typeattr`:

* `sysfile.power.addname_all_dirs`
* `sysfile.power.append_all_blk_files`
* `sysfile.power.append_all_chr_files`
* `sysfile.power.append_all_fifo_files`
* `sysfile.power.append_all_files`
* `sysfile.power.appendinherited_all_blk_files`
* `sysfile.power.appendinherited_all_chr_files`
* `sysfile.power.appendinherited_all_fifo_files`
* `sysfile.power.appendinherited_all_files`
* `sysfile.power.create_all`
* `sysfile.power.create_all_blk_files`
* `sysfile.power.create_all_chr_files`
* `sysfile.power.create_all_dirs`
* `sysfile.power.create_all_fifo_files`
* `sysfile.power.create_all_files`
* `sysfile.power.create_all_lnk_files`
* `sysfile.power.create_all_sock_files`
* `sysfile.power.deletename_all_dirs`
* `sysfile.power.delete_all`
* `sysfile.power.delete_all_blk_files`
* `sysfile.power.delete_all_chr_files`
* `sysfile.power.delete_all_dirs`
* `sysfile.power.delete_all_fifo_files`
* `sysfile.power.delete_all_files`
* `sysfile.power.delete_all_lnk_files`
* `sysfile.power.delete_all_sock_files`
* `sysfile.power.execute_all_files`
* `sysfile.power.getattr_all_files`
* `sysfile.power.getattr_all_lnk_files`
* `sysfile.power.list_all_dirs`
* `sysfile.power.listinherited_all_dirs`
* `sysfile.power.manage_all`
* `sysfile.power.manage_all_blk_files`
* `sysfile.power.manage_all_chr_files`
* `sysfile.power.manage_all_dirs`
* `sysfile.power.manage_all_fifo_files`
* `sysfile.power.manage_all_files`
* `sysfile.power.manage_all_lnk_files`
* `sysfile.power.manage_all_sock_files`
* `sysfile.power.mapexecute_all_chr_files`
* `sysfile.power.mapexecute_all_files`
* `sysfile.power.mounton_all`
* `sysfile.power.mounton_all_blk_files`
* `sysfile.power.mounton_all_chr_files`
* `sysfile.power.mounton_all_dirs`
* `sysfile.power.mounton_all_fifo_files`
* `sysfile.power.mounton_all_files`
* `sysfile.power.mounton_all_lnk_files`
* `sysfile.power.mounton_all_sock_files`
* `sysfile.power.obj_type`
* `sysfile.power.read_all`
* `sysfile.power.read_all_blk_files`
* `sysfile.power.read_all_chr_files`
* `sysfile.power.read_all_fifo_files`
* `sysfile.power.read_all_files`
* `sysfile.power.read_all_lnk_files`
* `sysfile.power.read_all_sock_files`
* `sysfile.power.readinherited_all_blk_files`
* `sysfile.power.readinherited_all_chr_files`
* `sysfile.power.readinherited_all_fifo_files`
* `sysfile.power.readinherited_all_files`
* `sysfile.power.readinherited_all_sock_files`
* `sysfile.power.readwrite_all`
* `sysfile.power.readwrite_all_blk_files`
* `sysfile.power.readwrite_all_chr_files`
* `sysfile.power.readwrite_all_dirs`
* `sysfile.power.readwrite_all_fifo_files`
* `sysfile.power.readwrite_all_files`
* `sysfile.power.readwrite_all_lnk_files`
* `sysfile.power.readwrite_all_sock_files`
* `sysfile.power.readwriteinherited_all_blk_files`
* `sysfile.power.readwriteinherited_all_chr_files`
* `sysfile.power.readwriteinherited_all_dirs`
* `sysfile.power.readwriteinherited_all_fifo_files`
* `sysfile.power.readwriteinherited_all_files`
* `sysfile.power.readwriteinherited_all_sock_files`
* `sysfile.power.relabel_all`
* `sysfile.power.relabel_all_blk_files`
* `sysfile.power.relabel_all_chr_files`
* `sysfile.power.relabel_all_dirs`
* `sysfile.power.relabel_all_fifo_files`
* `sysfile.power.relabel_all_files`
* `sysfile.power.relabel_all_lnk_files`
* `sysfile.power.relabel_all_sock_files`
* `sysfile.power.relabelfrom_all`
* `sysfile.power.relabelfrom_all_blk_files`
* `sysfile.power.relabelfrom_all_chr_files`
* `sysfile.power.relabelfrom_all_dirs`
* `sysfile.power.relabelfrom_all_fifo_files`
* `sysfile.power.relabelfrom_all_files`
* `sysfile.power.relabelfrom_all_lnk_files`
* `sysfile.power.relabelfrom_all_sock_files`
* `sysfile.power.relabelto_all`
* `sysfile.power.relabelto_all_blk_files`
* `sysfile.power.relabelto_all_chr_files`
* `sysfile.power.relabelto_all_dirs`
* `sysfile.power.relabelto_all_fifo_files`
* `sysfile.power.relabelto_all_files`
* `sysfile.power.relabelto_all_lnk_files`
* `sysfile.power.relabelto_all_sock_files`
* `sysfile.power.rename_all`
* `sysfile.power.rename_all_blk_files`
* `sysfile.power.rename_all_chr_files`
* `sysfile.power.rename_all_dirs`
* `sysfile.power.rename_all_fifo_files`
* `sysfile.power.rename_all_files`
* `sysfile.power.rename_all_lnk_files`
* `sysfile.power.rename_all_sock_files`
* `sysfile.power.search_all_dirs`
* `sysfile.power.write_all`
* `sysfile.power.write_all_blk_files`
* `sysfile.power.write_all_chr_files`
* `sysfile.power.write_all_dirs`
* `sysfile.power.write_all_fifo_files`
* `sysfile.power.write_all_files`
* `sysfile.power.write_all_lnk_files`
* `sysfile.power.write_all_sock_files`
* `sysfile.power.writeinherited_all_blk_files`
* `sysfile.power.writeinherited_all_chr_files`
* `sysfile.power.writeinherited_all_dirs`
* `sysfile.power.writeinherited_all_fifo_files`
* `sysfile.power.writeinherited_all_files`
* `sysfile.power.writeinherited_all_sock_files`
* `sysfile.power.dontaudit_manage_all_dirs`
* `sysfile.power.dontaudit_manage_all_files`
* `sysfile.power.dontaudit_manage_all_lnk_files`

# Private Sys File Types

Private types to be associated with Sys files are to be declared
in either `src/sysfile/blocksysfile`, `src/sysfile/bussysfile`,
`src/sysfile/classsysfile`, `src/sysfile/devsysfile`,
`src/sysfile/devicessysfile`, `src/sysfile/firmwaresysfile`,
`src/sysfile/fssysfile`, `src/sysfile/hypervisorsysfile`,
`src/sysfile/kernelsysfile`, `src/sysfile/modulesysfile` or
`src/sysfile/powersysfile` directories depending on the location a
given Sys file type is associated with. There are currently various
existing examples available in the `src/sysfile/classsysfile` and
`src/sysfile/fssysfile` directories but if you would for example want
to declare a private `mydevicetree.sysfile` sys file type to be
associated with the `/sys/firmware/devicetree` location:

```
# create directory if it does not exist
mkdir -p src/sysfile/firmwaresysfile

# create module
cat > src/sysfile/firmware/mydevicetreefirmwaresysfile.cil <<EOF
(block mydevicetree

       ;;
       ;; Contexts
       ;;

       (genfscon
       "sysfs"
       "/firmware/devicetree"
       sysfile_file_context)

       ;;
       ;; Policy
       ;;

       (blockinherit .sysfile.firmware.obj_template))
EOF

# build policy
make

# analyze policy
seinfo policy.31 -x -t mydevicetree.sysfile
seinfo policy.31 -x --genfscon sysfs
sesearch policy.31 -A -t mydevicetree.sysfile
```
A comprehensive collection of macros is now available to facilitate
access to Sys Firmware files associated with the
`mydevicetree.sysfile` Sys Firmware file type:

* `mydevicetree.addname_sysfile_dirs`
* `mydevicetree.append_sysfile_blk_files`
* `mydevicetree.append_sysfile_chr_files`
* `mydevicetree.append_sysfile_fifo_files`
* `mydevicetree.append_sysfile_files`
* `mydevicetree.appendinherited_sysfile_blk_files`
* `mydevicetree.appendinherited_sysfile_chr_files`
* `mydevicetree.appendinherited_sysfile_fifo_files`
* `mydevicetree.appendinherited_sysfile_files`
* `mydevicetree.sysfile_obj_type_transition`
* `mydevicetree.create_sysfile`
* `mydevicetree.create_sysfile_blk_files`
* `mydevicetree.create_sysfile_chr_files`
* `mydevicetree.create_sysfile_dirs`
* `mydevicetree.create_sysfile_fifo_files`
* `mydevicetree.create_sysfile_files`
* `mydevicetree.create_sysfile_lnk_files`
* `mydevicetree.create_sysfile_sock_files`
* `mydevicetree.deletename_sysfile_dirs`
* `mydevicetree.delete_sysfile`
* `mydevicetree.delete_sysfile_blk_files`
* `mydevicetree.delete_sysfile_chr_files`
* `mydevicetree.delete_sysfile_dirs`
* `mydevicetree.delete_sysfile_fifo_files`
* `mydevicetree.delete_sysfile_files`
* `mydevicetree.delete_sysfile_lnk_files`
* `mydevicetree.delete_sysfile_sock_files`
* `mydevicetree.execute_sysfile_files`
* `mydevicetree.getattr_sysfile_files`
* `mydevicetree.getattr_sysfile_lnk_files`
* `mydevicetree.list_sysfile_dirs`
* `mydevicetree.listinherited_sysfile_dirs`
* `mydevicetree.manage_sysfile`
* `mydevicetree.manage_sysfile_blk_files`
* `mydevicetree.manage_sysfile_chr_files`
* `mydevicetree.manage_sysfile_dirs`
* `mydevicetree.manage_sysfile_fifo_files`
* `mydevicetree.manage_sysfile_files`
* `mydevicetree.manage_sysfile_lnk_files`
* `mydevicetree.manage_sysfile_sock_files`
* `mydevicetree.mapexecute_sysfile_chr_files`
* `mydevicetree.mapexecute_sysfile_files`
* `mydevicetree.mounton_sysfile`
* `mydevicetree.mounton_sysfile_blk_files`
* `mydevicetree.mounton_sysfile_chr_files`
* `mydevicetree.mounton_sysfile_dirs`
* `mydevicetree.mounton_sysfile_fifo_files`
* `mydevicetree.mounton_sysfile_files`
* `mydevicetree.mounton_sysfile_lnk_files`
* `mydevicetree.mounton_sysfile_sock_files`
* `mydevicetree.read_sysfile`
* `mydevicetree.read_sysfile_blk_files`
* `mydevicetree.read_sysfile_chr_files`
* `mydevicetree.read_sysfile_fifo_files`
* `mydevicetree.read_sysfile_files`
* `mydevicetree.read_sysfile_lnk_files`
* `mydevicetree.read_sysfile_sock_files`
* `mydevicetree.readinherited_sysfile_blk_files`
* `mydevicetree.readinherited_sysfile_chr_files`
* `mydevicetree.readinherited_sysfile_fifo_files`
* `mydevicetree.readinherited_sysfile_files`
* `mydevicetree.readinherited_sysfile_sock_files`
* `mydevicetree.readwrite_sysfile`
* `mydevicetree.readwrite_sysfile_blk_files`
* `mydevicetree.readwrite_sysfile_chr_files`
* `mydevicetree.readwrite_sysfile_dirs`
* `mydevicetree.readwrite_sysfile_fifo_files`
* `mydevicetree.readwrite_sysfile_files`
* `mydevicetree.readwrite_sysfile_lnk_files`
* `mydevicetree.readwrite_sysfile_sock_files`
* `mydevicetree.readwriteinherited_sysfile_blk_files`
* `mydevicetree.readwriteinherited_sysfile_chr_files`
* `mydevicetree.readwriteinherited_sysfile_dirs`
* `mydevicetree.readwriteinherited_sysfile_fifo_files`
* `mydevicetree.readwriteinherited_sysfile_files`
* `mydevicetree.readwriteinherited_sysfile_sock_files`
* `mydevicetree.relabel_sysfile`
* `mydevicetree.relabel_sysfile_blk_files`
* `mydevicetree.relabel_sysfile_chr_files`
* `mydevicetree.relabel_sysfile_dirs`
* `mydevicetree.relabel_sysfile_fifo_files`
* `mydevicetree.relabel_sysfile_files`
* `mydevicetree.relabel_sysfile_lnk_files`
* `mydevicetree.relabel_sysfile_sock_files`
* `mydevicetree.relabelfrom_sysfile`
* `mydevicetree.relabelfrom_sysfile_blk_files`
* `mydevicetree.relabelfrom_sysfile_chr_files`
* `mydevicetree.relabelfrom_sysfile_dirs`
* `mydevicetree.relabelfrom_sysfile_fifo_files`
* `mydevicetree.relabelfrom_sysfile_files`
* `mydevicetree.relabelfrom_sysfile_lnk_files`
* `mydevicetree.relabelfrom_sysfile_sock_files`
* `mydevicetree.relabelto_sysfile`
* `mydevicetree.relabelto_sysfile_blk_files`
* `mydevicetree.relabelto_sysfile_chr_files`
* `mydevicetree.relabelto_sysfile_dirs`
* `mydevicetree.relabelto_sysfile_fifo_files`
* `mydevicetree.relabelto_sysfile_files`
* `mydevicetree.relabelto_sysfile_lnk_files`
* `mydevicetree.relabelto_sysfile_sock_files`
* `mydevicetree.rename_sysfile`
* `mydevicetree.rename_sysfile_blk_files`
* `mydevicetree.rename_sysfile_chr_files`
* `mydevicetree.rename_sysfile_dirs`
* `mydevicetree.rename_sysfile_fifo_files`
* `mydevicetree.rename_sysfile_files`
* `mydevicetree.rename_sysfile_lnk_files`
* `mydevicetree.rename_sysfile_sock_files`
* `mydevicetree.search_sysfile_dirs`
* `mydevicetree.sysfile_obj_type_transition`
* `mydevicetree.write_sysfile`
* `mydevicetree.write_sysfile_blk_files`
* `mydevicetree.write_sysfile_chr_files`
* `mydevicetree.write_sysfile_dirs`
* `mydevicetree.write_sysfile_fifo_files`
* `mydevicetree.write_sysfile_files`
* `mydevicetree.write_sysfile_lnk_files`
* `mydevicetree.write_sysfile_sock_files`
* `mydevicetree.writeinherited_sysfile_blk_files`
* `mydevicetree.writeinherited_sysfile_chr_files`
* `mydevicetree.writeinherited_sysfile_dirs`
* `mydevicetree.writeinherited_sysfile_fifo_files`
* `mydevicetree.writeinherited_sysfile_files`
* `mydevicetree.writeinherited_sysfile_sock_files`

Rules that reference all Sys files, or all Sys Firmware files are now
also automatically associated with the `mydevicetree.sysfile` Sys
Firmware file type.
